@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -24,7 +24,6 @@
 #include <config.h>
 
 #include <glib/gi18n.h>
-#include <libgnome/gnome-util.h>
 #include <table/e-table-scrolled.h>
 #include <table/e-table-model.h>
 #include <misc/e-gui-utils.h>
@@ -32,7 +31,6 @@
 #include <filter/rule-editor.h>
 #include <widgets/menus/gal-view-etable.h>
 #include <e-util/e-xml-utils.h>
-#include <libgnomeui/gnome-dialog-util.h>
 
 #include "addressbook/printing/e-contact-print.h"
 #include "addressbook/gui/widgets/eab-popup.h"
@@ -47,7 +45,6 @@
 #include "gal-view-minicard.h"
 #include "gal-view-factory-minicard.h"
 
-#include "eab-marshal.h"
 #include "e-addressbook-view.h"
 #include "e-addressbook-model.h"
 #include "eab-gui-util.h"
@@ -103,7 +100,7 @@ static void categories_changed_cb (gpointer object, gpointer user_data);
 static void make_suboptions             (EABView *view);
 static void query_changed               (ESearchBar *esb, EABView *view);
 static void search_activated            (ESearchBar *esb, EABView *view);
-static void search_menu_activated       (ESearchBar *esb, int id, EABView *view);
+static void search_menu_activated       (ESearchBar *esb, gint id, EABView *view);
 static GList *get_master_list (gboolean force_rebuild);
 
 static gpointer parent_class;
@@ -114,7 +111,7 @@ enum {
 	PROP_BOOK,
 	PROP_SOURCE,
 	PROP_QUERY,
-	PROP_TYPE,
+	PROP_TYPE
 };
 
 enum {
@@ -134,14 +131,14 @@ enum DndTargetType {
 
 typedef struct EABSearchBarItem {
 	ESearchBarItem search;
-	char *image;
+	gchar *image;
 }EABSearchBarItem;
 
 static GtkTargetEntry drag_types[] = {
-	{ SOURCE_VCARD_TYPE, 0, DND_TARGET_TYPE_SOURCE_VCARD },
-	{ VCARD_TYPE, 0, DND_TARGET_TYPE_VCARD }
+	{ (gchar *) SOURCE_VCARD_TYPE, 0, DND_TARGET_TYPE_SOURCE_VCARD },
+	{ (gchar *) VCARD_TYPE, 0, DND_TARGET_TYPE_VCARD }
 };
-static const int num_drag_types = sizeof (drag_types) / sizeof (drag_types[0]);
+static const gint num_drag_types = sizeof (drag_types) / sizeof (drag_types[0]);
 
 static guint eab_view_signals [LAST_SIGNAL] = {0, };
 
@@ -152,7 +149,7 @@ static GalViewCollection *collection = NULL;
 enum {
 	ESB_FULL_NAME,
 	ESB_EMAIL,
-	ESB_ANY,
+	ESB_ANY
 };
 
 #if 0
@@ -415,8 +412,8 @@ eab_view_new (void)
 	GtkWidget *widget = GTK_WIDGET (g_object_new (E_TYPE_AB_VIEW, NULL));
 	EABView *eav = EAB_VIEW (widget);
 	FilterPart *part;
-	char *xmlfile;
-	char *userfile;
+	gchar *xmlfile;
+	gchar *userfile;
 
 	/* create our model */
 	eav->model = eab_model_new ();
@@ -546,16 +543,17 @@ init_collection (void)
 {
 	GalViewFactory *factory;
 	ETableSpecification *spec;
-	char *galview;
-	char *addressbookdir;
-	char *etspecfile;
+	gchar *galview;
+	gchar *addressbookdir;
+	gchar *etspecfile;
 
 	if (collection == NULL) {
 		collection = gal_view_collection_new();
 
 		gal_view_collection_set_title (collection, _("Address Book"));
 
-		galview = gnome_util_prepend_user_home("/.evolution/addressbook/views");
+		galview = g_build_filename (
+			e_get_user_data_dir (), "addressbook", "views", NULL);
 		addressbookdir = g_build_filename (EVOLUTION_GALVIEWSDIR,
 						   "addressbook",
 						   NULL);
@@ -628,7 +626,7 @@ display_view(GalViewInstance *instance,
 }
 
 static void
-view_preview(BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_EventType type, const char *state, void *data)
+view_preview(BonoboUIComponent *uic, const gchar *path, Bonobo_UIComponent_EventType type, const gchar *state, gpointer data)
 {
 	/* XXX this should use the addressbook's global gconf client */
 	GConfClient *gconf_client;
@@ -795,7 +793,7 @@ static GList *
 get_contact_list (EABPopupTargetSelect *t)
 {
 	GList *list = NULL;
-	int i;
+	gint i;
 
 	for (i=0;i<t->cards->len;i++)
 		list = g_list_prepend(list, t->cards->pdata[i]);
@@ -804,7 +802,7 @@ get_contact_list (EABPopupTargetSelect *t)
 }
 
 static void
-save_as (EPopup *ep, EPopupItem *pitem, void *data)
+save_as (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	/*ContactAndBook *contact_and_book = data;*/
 	GList *contacts = get_contact_list ((EABPopupTargetSelect *)ep->target);
@@ -816,7 +814,7 @@ save_as (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-send_as (EPopup *ep, EPopupItem *pitem, void *data)
+send_as (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	/*ContactAndBook *contact_and_book = data;*/
 	GList *contacts = get_contact_list ((EABPopupTargetSelect *)ep->target);
@@ -828,7 +826,7 @@ send_as (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-send_to (EPopup *ep, EPopupItem *pitem, void *data)
+send_to (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	/*ContactAndBook *contact_and_book = data;*/
 	GList *contacts = get_contact_list ((EABPopupTargetSelect *)ep->target);
@@ -840,7 +838,7 @@ send_to (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-print (EPopup *ep, EPopupItem *pitem, void *data)
+print (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	/*ContactAndBook *contact_and_book = data;*/
 	EABPopupTargetSelect *t = (EABPopupTargetSelect *)ep->target;
@@ -854,7 +852,7 @@ print (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-copy (EPopup *ep, EPopupItem *pitem, void *data)
+copy (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	ContactAndBook *contact_and_book = data;
 
@@ -862,7 +860,7 @@ copy (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-paste (EPopup *ep, EPopupItem *pitem, void *data)
+paste (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	ContactAndBook *contact_and_book = data;
 
@@ -870,7 +868,7 @@ paste (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-cut (EPopup *ep, EPopupItem *pitem, void *data)
+cut (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	ContactAndBook *contact_and_book = data;
 
@@ -878,7 +876,7 @@ cut (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-delete (EPopup *ep, EPopupItem *pitem, void *data)
+delete (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	ContactAndBook *contact_and_book = data;
 
@@ -886,7 +884,7 @@ delete (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-copy_to_folder (EPopup *ep, EPopupItem *pitem, void *data)
+copy_to_folder (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	ContactAndBook *contact_and_book = data;
 
@@ -894,7 +892,7 @@ copy_to_folder (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-move_to_folder (EPopup *ep, EPopupItem *pitem, void *data)
+move_to_folder (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	ContactAndBook *contact_and_book = data;
 
@@ -902,16 +900,15 @@ move_to_folder (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-open_contact (EPopup *ep, EPopupItem *pitem, void *data)
+open_contact (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	ContactAndBook *contact_and_book = data;
 
 	eab_view_view (contact_and_book->view);
 }
 
-
 static void
-new_card (EPopup *ep, EPopupItem *pitem, void *data)
+new_card (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	/*ContactAndBook *contact_and_book = data;*/
 	EContact *contact = e_contact_new();
@@ -921,7 +918,7 @@ new_card (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-new_list (EPopup *ep, EPopupItem *pitem, void *data)
+new_list (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	/*ContactAndBook *contact_and_book = data;*/
 	EContact *contact = e_contact_new ();
@@ -931,33 +928,33 @@ new_list (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static EPopupItem eabv_popup_items[] = {
-	{ E_POPUP_ITEM, "05.open", N_("_Open"), open_contact, NULL, NULL, EAB_POPUP_SELECT_ANY|EAB_POPUP_SELECT_EDITABLE },
-	{ E_POPUP_BAR, "10.bar" },
-	{ E_POPUP_ITEM, "10.new",  N_("_New Contact..."), new_card, NULL, "contact-new", 0, EAB_POPUP_SELECT_EDITABLE},
-	{ E_POPUP_ITEM, "15.newlist", N_("New Contact _List..."), new_list, NULL, "stock_contact-list", 0, EAB_POPUP_SELECT_EDITABLE },
+	{ E_POPUP_ITEM, (gchar *) "05.open", (gchar *) N_("_Open"), open_contact, NULL, NULL, EAB_POPUP_SELECT_ANY|EAB_POPUP_SELECT_EDITABLE },
+	{ E_POPUP_BAR, (gchar *) "10.bar" },
+	{ E_POPUP_ITEM, (gchar *) "10.new",  (gchar *) N_("_New Contact..."), new_card, NULL, (gchar *) "contact-new", 0, EAB_POPUP_SELECT_EDITABLE},
+	{ E_POPUP_ITEM, (gchar *) "15.newlist", (gchar *) N_("New Contact _List..."), new_list, NULL, (gchar *) "stock_contact-list", 0, EAB_POPUP_SELECT_EDITABLE },
 
-	{ E_POPUP_BAR, "20.bar" },
-	{ E_POPUP_ITEM, "30.saveas", N_("_Save as vCard..."), save_as, NULL, "document-save-as", 0, EAB_POPUP_SELECT_ANY },
-	{ E_POPUP_ITEM, "40.forward", N_("_Forward Contact"), send_as, NULL, "mail-forward", EAB_POPUP_SELECT_ONE },
-	{ E_POPUP_ITEM, "40.forward", N_("_Forward Contacts"), send_as, NULL, "mail-forward", EAB_POPUP_SELECT_MANY },
-	{ E_POPUP_ITEM, "50.mailto", N_("Send _Message to Contact"), send_to, NULL, "mail-message-new", EAB_POPUP_SELECT_ONE|EAB_POPUP_SELECT_EMAIL|EAB_POPUP_CONTACT },
-	{ E_POPUP_ITEM, "50.mailto", N_("Send _Message to List"), send_to, NULL, "mail-message-new", EAB_POPUP_SELECT_ONE|EAB_POPUP_SELECT_EMAIL|EAB_POPUP_LIST },
-	{ E_POPUP_ITEM, "50.mailto", N_("Send _Message to Contacts"), send_to, NULL, "mail-message-new", EAB_POPUP_SELECT_MANY|EAB_POPUP_SELECT_EMAIL },
-	{ E_POPUP_ITEM, "60.print", N_("_Print"), print, NULL, "document-print", 0, EAB_POPUP_SELECT_ANY },
+	{ E_POPUP_BAR, (gchar *) "20.bar" },
+	{ E_POPUP_ITEM, (gchar *) "30.saveas", (gchar *) N_("_Save as vCard..."), save_as, NULL, (gchar *) "document-save-as", 0, EAB_POPUP_SELECT_ANY },
+	{ E_POPUP_ITEM, (gchar *) "40.forward", (gchar *) N_("_Forward Contact"), send_as, NULL, (gchar *) "mail-forward", EAB_POPUP_SELECT_ONE },
+	{ E_POPUP_ITEM, (gchar *) "40.forward", (gchar *) N_("_Forward Contacts"), send_as, NULL, (gchar *) "mail-forward", EAB_POPUP_SELECT_MANY },
+	{ E_POPUP_ITEM, (gchar *) "50.mailto", (gchar *) N_("Send _Message to Contact"), send_to, NULL, (gchar *) "mail-message-new", EAB_POPUP_SELECT_ONE|EAB_POPUP_SELECT_EMAIL|EAB_POPUP_CONTACT },
+	{ E_POPUP_ITEM, (gchar *) "50.mailto", (gchar *) N_("Send _Message to List"), send_to, NULL, (gchar *) "mail-message-new", EAB_POPUP_SELECT_ONE|EAB_POPUP_SELECT_EMAIL|EAB_POPUP_LIST },
+	{ E_POPUP_ITEM, (gchar *) "50.mailto", (gchar *) N_("Send _Message to Contacts"), send_to, NULL, (gchar *) "mail-message-new", EAB_POPUP_SELECT_MANY|EAB_POPUP_SELECT_EMAIL },
+	{ E_POPUP_ITEM, (gchar *) "60.print", (gchar *) N_("_Print"), print, NULL, (gchar *) "document-print", 0, EAB_POPUP_SELECT_ANY },
 
-	{ E_POPUP_BAR, "70.bar" },
-	{ E_POPUP_ITEM, "80.copyto", N_("Cop_y to Address Book..."), copy_to_folder, NULL, NULL, 0, EAB_POPUP_SELECT_ANY },
-	{ E_POPUP_ITEM, "90.moveto", N_("Mo_ve to Address Book..."), move_to_folder, NULL, NULL, 0, EAB_POPUP_SELECT_ANY|EAB_POPUP_SELECT_EDITABLE },
+	{ E_POPUP_BAR, (gchar *) "70.bar" },
+	{ E_POPUP_ITEM, (gchar *) "80.copyto", (gchar *) N_("Cop_y to Address Book..."), copy_to_folder, NULL, NULL, 0, EAB_POPUP_SELECT_ANY },
+	{ E_POPUP_ITEM, (gchar *) "90.moveto", (gchar *) N_("Mo_ve to Address Book..."), move_to_folder, NULL, NULL, 0, EAB_POPUP_SELECT_ANY|EAB_POPUP_SELECT_EDITABLE },
 
-	{ E_POPUP_BAR, "a0.bar" },
-	{ E_POPUP_ITEM, "b0.cut", N_("Cu_t"), cut, NULL, "edit-cut", 0, EAB_POPUP_SELECT_ANY|EAB_POPUP_SELECT_EDITABLE },
-	{ E_POPUP_ITEM, "c0.copy", N_("_Copy"), copy, NULL, "edit-copy", 0, EAB_POPUP_SELECT_ANY },
-	{ E_POPUP_ITEM, "d0.paste", N_("P_aste"), paste, NULL, "edit-paste", 0, EAB_POPUP_SELECT_EDITABLE },
-	{ E_POPUP_ITEM, "e0.delete", N_("_Delete"), delete, NULL, "edit-delete", 0, EAB_POPUP_SELECT_EDITABLE|EAB_POPUP_SELECT_ANY },
+	{ E_POPUP_BAR, (gchar *) "a0.bar" },
+	{ E_POPUP_ITEM, (gchar *) "b0.cut", (gchar *) N_("Cu_t"), cut, NULL, (gchar *) "edit-cut", 0, EAB_POPUP_SELECT_ANY|EAB_POPUP_SELECT_EDITABLE },
+	{ E_POPUP_ITEM, (gchar *) "c0.copy", (gchar *) N_("_Copy"), copy, NULL, (gchar *) "edit-copy", 0, EAB_POPUP_SELECT_ANY },
+	{ E_POPUP_ITEM, (gchar *) "d0.paste", (gchar *) N_("P_aste"), paste, NULL, (gchar *) "edit-paste", 0, EAB_POPUP_SELECT_EDITABLE },
+	{ E_POPUP_ITEM, (gchar *) "e0.delete", (gchar *) N_("_Delete"), delete, NULL, (gchar *) "edit-delete", 0, EAB_POPUP_SELECT_EDITABLE|EAB_POPUP_SELECT_ANY },
 };
 
 static void
-get_card_1(gint model_row, void *data)
+get_card_1(gint model_row, gpointer data)
 {
 	ContactAndBook *contact_and_book = data;
 	EContact *contact;
@@ -968,7 +965,7 @@ get_card_1(gint model_row, void *data)
 }
 
 static void
-eabv_popup_free(EPopup *ep, GSList *list, void *data)
+eabv_popup_free(EPopup *ep, GSList *list, gpointer data)
 {
 	ContactAndBook *cab = data;
 	ESelectionModel *selection;
@@ -989,7 +986,7 @@ do_popup_menu(EABView *view, GdkEvent *event)
 	EABPopup *ep;
 	EABPopupTargetSelect *t;
 	GSList *menus = NULL;
-	int i;
+	gint i;
 	GtkMenu *menu;
 	GPtrArray *cards = g_ptr_array_new();
 	ContactAndBook *contact_and_book;
@@ -1027,7 +1024,7 @@ do_popup_menu(EABView *view, GdkEvent *event)
 }
 
 static void
-render_contact (int row, EABView *view)
+render_contact (gint row, EABView *view)
 {
 	EContact *contact = eab_model_get_contact (view->model, row);
 
@@ -1101,8 +1098,8 @@ table_white_space_event(ETableScrolled *table, GdkEvent *event, EABView *view)
 
 static void
 table_drag_data_get (ETable             *table,
-		     int                 row,
-		     int                 col,
+		     gint                 row,
+		     gint                 col,
 		     GdkDragContext     *context,
 		     GtkSelectionData   *selection_data,
 		     guint               info,
@@ -1119,7 +1116,7 @@ table_drag_data_get (ETable             *table,
 
 	switch (info) {
 	case DND_TARGET_TYPE_VCARD: {
-		char *value;
+		gchar *value;
 
 		value = eab_contact_list_to_string (contact_list);
 
@@ -1131,7 +1128,7 @@ table_drag_data_get (ETable             *table,
 		break;
 	}
 	case DND_TARGET_TYPE_SOURCE_VCARD: {
-		char *value;
+		gchar *value;
 
 		value = eab_book_and_contact_list_to_string (view->book, contact_list);
 
@@ -1223,12 +1220,11 @@ static void
 contacts_removed (EABModel *model, gpointer data, EABView *eav)
 {
 	GArray *indices = (GArray *) data;
-	int count = indices->len;
+	gint count = indices->len;
 	gint i;
 
 	for (i = 0; i < count; i ++) {
 
-
 		if (eav->displayed_contact == g_array_index (indices, gint, i)) {
 
 			/* if the contact that's presently displayed is changed, clear the display */
@@ -1286,7 +1282,7 @@ create_table_view (EABView *view)
 {
 	ETableModel *adapter;
 	GtkWidget *table;
-	char *etspecfile;
+	gchar *etspecfile;
 
 	adapter = eab_table_adapter_new(view->model);
 
@@ -1360,9 +1356,9 @@ static void
 search_activated (ESearchBar *esb, EABView *v)
 {
 	GList *master_list;
-	char *search_word, *search_query, *view_sexp;
-	const char *category_name;
-	int search_type, subid;
+	gchar *search_word, *search_query, *view_sexp;
+	const gchar *category_name;
+	gint search_type, subid;
 
 	g_object_get(esb,
 		     "text", &search_word,
@@ -1370,7 +1366,8 @@ search_activated (ESearchBar *esb, EABView *v)
 		     NULL);
 
 	if (search_type == E_FILTERBAR_ADVANCED_ID) {
-		// gtk_widget_show(eab_search_dialog_new(v));
+		/* rebuild view immediately */
+		query_changed (esb, v);
 	}
 	else {
 		if ((search_word && strlen (search_word))) {
@@ -1403,8 +1400,12 @@ search_activated (ESearchBar *esb, EABView *v)
 
 		if (subid) {
 			master_list = get_master_list (FALSE);
-			category_name = g_list_nth_data (master_list, subid-1);
-			view_sexp = g_strdup_printf ("(is \"category_list\" \"%s\")", category_name);
+			if (subid < 3) {
+				view_sexp = g_strdup ("(not (and (exists \"CATEGORIES\") (not (is \"CATEGORIES\" \"\"))))");
+			} else {
+				category_name = g_list_nth_data (master_list, subid-3);
+				view_sexp = g_strdup_printf ("(is \"category_list\" \"%s\")", category_name);
+			}
 			search_query = g_strconcat ("(and ", view_sexp, search_query, ")", NULL);
 			g_free (view_sexp);
 		}
@@ -1424,7 +1425,7 @@ search_activated (ESearchBar *esb, EABView *v)
 }
 
 static void
-search_menu_activated (ESearchBar *esb, int id, EABView *view)
+search_menu_activated (ESearchBar *esb, gint id, EABView *view)
 {
 	if (id == E_FILTERBAR_ADVANCED_ID)
 		e_search_bar_set_item_id (esb, id);
@@ -1433,8 +1434,8 @@ search_menu_activated (ESearchBar *esb, int id, EABView *view)
 static void
 query_changed (ESearchBar *esb, EABView *view)
 {
-	int search_type;
-	char *query;
+	gint search_type;
+	gchar *query;
 
 	search_type = e_search_bar_get_item_id(esb);
 	if (search_type == E_FILTERBAR_ADVANCED_ID) {
@@ -1444,13 +1445,13 @@ query_changed (ESearchBar *esb, EABView *view)
 	}
 }
 
-static int
-compare_subitems (const void *a, const void *b)
+static gint
+compare_subitems (gconstpointer a, gconstpointer b)
 {
 	const ESearchBarItem *subitem_a = a;
 	const ESearchBarItem *subitem_b = b;
-	char *collate_a, *collate_b;
-	int ret;
+	gchar *collate_a, *collate_b;
+	gint ret;
 
 	collate_a = g_utf8_collate_key (subitem_a->text, -1);
 	collate_b = g_utf8_collate_key (subitem_b->text, -1);
@@ -1473,7 +1474,7 @@ generate_viewoption_menu (EABSearchBarItem *subitems)
 
 	for (i = 0; subitems[i].search.id != -1; ++i) {
 		if (subitems[i].search.text) {
-			char *str = NULL;
+			gchar *str = NULL;
 			str = e_str_without_underscores (subitems[i].search.text);
 			menu_item = gtk_image_menu_item_new_with_label (str);
                         if (subitems[i].image) {
@@ -1518,24 +1519,32 @@ make_suboptions (EABView *view)
 
 	master_list = get_master_list (FALSE);
 	N = g_list_length (master_list);
-	subitems = g_new (EABSearchBarItem, N+2);
+	subitems = g_new (EABSearchBarItem, N+4);
 
 	subitems[0].search.id = 0;
 	subitems[0].search.text = g_strdup (_("Any Category"));
 	subitems[0].image = NULL;
 
+	subitems[1].search.text = g_strdup (_("Unmatched"));
+	subitems[1].search.id = 1;
+	subitems[1].image = NULL;
+
+	subitems[2].search.text = NULL;
+	subitems[2].search.id = 0;
+	subitems[2].image = NULL;
+
 	for (i=0; i<N; ++i) {
-		const char *category = g_list_nth_data (master_list, i);
-		subitems[i+1].search.id = i+1;
-		subitems[i+1].search.text = g_strdup (category);
-		subitems[i+1].image = (char *)e_categories_get_icon_file_for (category);
+		const gchar *category = g_list_nth_data (master_list, i);
+		subitems[i+3].search.id = i+3;
+		subitems[i+3].search.text = g_strdup (category);
+		subitems[i+3].image = (gchar *)e_categories_get_icon_file_for (category);
 	}
 
-	subitems[N+1].search.id = -1;
-	subitems[N+1].search.text = NULL;
-	subitems[N+1].image = NULL;
+	subitems[N+3].search.id = -1;
+	subitems[N+3].search.text = NULL;
+	subitems[N+3].image = NULL;
 
-	qsort (subitems + 1, N, sizeof (subitems[0]), compare_subitems);
+	qsort (subitems + 3, N, sizeof (subitems[0]), compare_subitems);
 	menu = generate_viewoption_menu (subitems);
 	e_search_bar_set_viewoption_menu ((ESearchBar *)view->search, menu);
 
@@ -1560,7 +1569,7 @@ get_master_list (gboolean force_rebuild)
 		GList *l, *p = e_categories_get_list ();
 
 		for (l = p; l; l = l->next) {
-			if (e_categories_is_searchable ((const char *) l->data))
+			if (e_categories_is_searchable ((const gchar *) l->data))
 				category_list = g_list_prepend (category_list, l->data);
 		}
 
@@ -1726,10 +1735,10 @@ static void delete_contacts_cb (EBook *book,  EBookStatus status,  gpointer clos
 		case E_BOOK_ERROR_OK :
 		case E_BOOK_ERROR_CANCELLED :
 			break;
-	 	case E_BOOK_ERROR_PERMISSION_DENIED :
-                	e_error_run (NULL, "addressbook:contact-delete-error-perm", NULL);
+		case E_BOOK_ERROR_PERMISSION_DENIED :
+			e_error_run (NULL, "addressbook:contact-delete-error-perm", NULL);
 			break;
-	  	default :
+		default :
 			/* Unknown error */
 			eab_error_dialog (_("Failed to delete contact"), status);
 			break;
@@ -1745,7 +1754,7 @@ eab_view_delete_selection(EABView *view, gboolean is_delete)
 	ETable *etable = NULL;
 	EMinicardView *card_view;
 	ESelectionModel *selection_model = NULL;
-	char *name = NULL;
+	gchar *name = NULL;
 	gint row = 0, select;
 
 	list = get_selected_contacts (view);
@@ -1786,7 +1795,7 @@ eab_view_delete_selection(EABView *view, gboolean is_delete)
 		for (l=list;l;l=g_list_next(l)) {
 			contact = l->data;
 
-			ids = g_list_prepend (ids, (char*)e_contact_get_const (contact, E_CONTACT_UID));
+			ids = g_list_prepend (ids, (gchar *)e_contact_get_const (contact, E_CONTACT_UID));
 		}
 
 		/* Remove the cards all at once. */
@@ -1853,7 +1862,7 @@ selection_get (GtkWidget *invisible,
 	       guint time_stamp,
 	       EABView *view)
 {
-	char *value;
+	gchar *value;
 
 	value = eab_contact_list_to_string (view->clipboard_contacts);
 
@@ -1885,14 +1894,14 @@ selection_received (GtkWidget *invisible,
 	} else {
 		GList *contact_list;
 		GList *l;
-		char *str = NULL;
+		gchar *str = NULL;
 
 		if (selection_data->data [selection_data->length - 1] != 0) {
 			str = g_malloc0 (selection_data->length + 1);
 			memcpy (str, selection_data->data, selection_data->length);
 			contact_list = eab_contact_list_from_string (str);
 		} else
-			contact_list = eab_contact_list_from_string ((char *)selection_data->data);
+			contact_list = eab_contact_list_from_string ((gchar *)selection_data->data);
 
 		for (l = contact_list; l; l = l->next) {
 			EContact *contact = l->data;
@@ -1908,7 +1917,7 @@ selection_received (GtkWidget *invisible,
 }
 
 static void
-add_to_list (int model_row, gpointer closure)
+add_to_list (gint model_row, gpointer closure)
 {
 	GList **list = closure;
 	*list = g_list_prepend (*list, GINT_TO_POINTER (model_row));
@@ -1935,7 +1944,7 @@ void
 eab_view_save_as (EABView *view, gboolean all)
 {
 	GList *list = NULL;
-	EBook *book ;
+	EBook *book;
 
 	g_object_get(view->model,
 		     "book", &book,
@@ -1944,7 +1953,7 @@ eab_view_save_as (EABView *view, gboolean all)
 	if (all) {
 		EBookQuery *query = e_book_query_any_field_contains("");
 		e_book_get_contacts(book, query, &list, NULL);
-	        e_book_query_unref(query);
+		e_book_query_unref(query);
 	}
 	else {
 		list = get_selected_contacts(view);
@@ -2071,7 +2080,7 @@ view_transfer_contacts (EABView *view, gboolean delete_from_source, gboolean all
 	if (all) {
 		EBookQuery *query = e_book_query_any_field_contains("");
 		e_book_get_contacts(book, query, &contacts, NULL);
-	        e_book_query_unref(query);
+		e_book_query_unref(query);
 	}
 	else {
 		contacts = get_selected_contacts (view);
@@ -2094,7 +2103,6 @@ eab_view_move_to_folder (EABView *view, gboolean all)
 	view_transfer_contacts (view, TRUE, all);
 }
 
-
 static gboolean
 eab_view_selection_nonempty (EABView  *view)
 {
