@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -46,7 +46,6 @@
 #include <e-pilot-map.h>
 #include <e-pilot-settings.h>
 #include <e-pilot-util.h>
-#include <e-config-listener.h>
 #include <libecalendar-common-conduit.h>
 
 GnomePilotConduit * conduit_get_gpilot_conduit (guint32);
@@ -86,7 +85,7 @@ struct _EMemoLocalRecord {
 	struct Memo *memo;
 };
 
-int lastDesktopUniqueID;
+gint lastDesktopUniqueID;
 
 static void
 memoconduit_destroy_record (EMemoLocalRecord *local)
@@ -118,7 +117,6 @@ memoconduit_load_configuration (guint32 pilot_id)
 	GnomePilotConduitConfig *config;
 	gchar prefix[256];
 
-
 	g_snprintf (prefix, 255, "e-memo-conduit/Pilot_%u", pilot_id);
 
 	c = g_new0 (EMemoConduitCfg,1);
@@ -126,7 +124,7 @@ memoconduit_load_configuration (guint32 pilot_id)
 
 	c->pilot_id = pilot_id;
 
-	management = gnome_pilot_conduit_management_new ("e_memo_conduit", GNOME_PILOT_CONDUIT_MGMT_ID);
+	management = gnome_pilot_conduit_management_new ((gchar *)"e_memo_conduit", GNOME_PILOT_CONDUIT_MGMT_ID);
 	g_object_ref_sink (management);
 	config = gnome_pilot_conduit_config_new (management, pilot_id);
 	g_object_ref_sink (config);
@@ -297,10 +295,10 @@ e_memo_context_destroy (EMemoConduitContext *ctxt)
 }
 
 /* Debug routines */
-static char *
+static gchar *
 print_local (EMemoLocalRecord *local)
 {
-	static char buff[ 64 ];
+	static gchar buff[ 64 ];
 
 	if (local == NULL) {
 		sprintf (buff, "[NULL]");
@@ -314,12 +312,13 @@ print_local (EMemoLocalRecord *local)
 		return buff;
 	}
 
-	return "";
+	strcpy (buff, "");
+	return buff;
 }
 
-static char *print_remote (GnomePilotRecord *remote)
+static gchar *print_remote (GnomePilotRecord *remote)
 {
-	static char buff[ 64 ];
+	static gchar buff[ 64 ];
 	struct Memo memo;
 #ifdef PILOT_LINK_0_12
 	pi_buffer_t *buffer;
@@ -356,7 +355,7 @@ static char *print_remote (GnomePilotRecord *remote)
 	return buff;
 }
 
-static int
+static gint
 start_calendar_server (EMemoConduitContext *ctxt)
 {
 	g_return_val_if_fail (ctxt != NULL, -2);
@@ -375,15 +374,16 @@ start_calendar_server (EMemoConduitContext *ctxt)
 static icaltimezone *
 get_default_timezone (void)
 {
-	EConfigListener *listener;
+	GConfClient *client;
 	icaltimezone *timezone = NULL;
-	char *location;
+	const gchar *key;
+	gchar *location;
 
-	listener = e_config_listener_new ();
+	client = gconf_client_get_default ();
+	key = "/apps/evolution/calendar/display/timezone";
+	location = gconf_client_get_string (client, key, NULL);
 
-	location = e_config_listener_get_string_with_default (listener,
-		"/apps/evolution/calendar/display/timezone", "UTC", NULL);
-	if (!location || !location[0]) {
+	if (location == NULL || *location == '\0') {
 		g_free (location);
 		location = g_strdup ("UTC");
 	}
@@ -391,15 +391,15 @@ get_default_timezone (void)
 	timezone = icaltimezone_get_builtin_timezone (location);
 	g_free (location);
 
-	g_object_unref (listener);
+	g_object_unref (client);
 
 	return timezone;
 }
 
-static char *
+static gchar *
 map_name (EMemoConduitContext *ctxt)
 {
-	char *filename;
+	gchar *filename;
 
 	filename = g_strdup_printf ("%s/.evolution/memos/local/system/pilot-map-memo-%d.xml", g_get_home_dir (), ctxt->cfg->pilot_id);
 
@@ -413,7 +413,7 @@ next_changed_item (EMemoConduitContext *ctxt, GList *changes)
 	GList *l;
 
 	for (l = changes; l != NULL; l = l->next) {
-		const char *uid;
+		const gchar *uid;
 
 		ccc = l->data;
 
@@ -426,7 +426,7 @@ next_changed_item (EMemoConduitContext *ctxt, GList *changes)
 }
 
 static void
-compute_status (EMemoConduitContext *ctxt, EMemoLocalRecord *local, const char *uid)
+compute_status (EMemoConduitContext *ctxt, EMemoLocalRecord *local, const gchar *uid)
 {
 	ECalChange *ccc;
 
@@ -461,7 +461,7 @@ local_record_to_pilot_record (EMemoLocalRecord *local,
 #ifdef PILOT_LINK_0_12
 	pi_buffer_t * buffer;
 #else
-	static char record[0xffff];
+	static gchar record[0xffff];
 #endif
 
 	memset(&p, 0, sizeof (p));
@@ -494,7 +494,7 @@ local_record_to_pilot_record (EMemoLocalRecord *local,
 
 	pi_buffer_free(buffer);
 #else
-	p.record = (unsigned char *)record;
+	p.record = (guchar *)record;
 	p.length = pack_Memo (local->memo, p.record, 0xffff);
 #endif
 	return p;
@@ -506,7 +506,7 @@ local_record_to_pilot_record (EMemoLocalRecord *local,
 static void
 local_record_from_comp (EMemoLocalRecord *local, ECalComponent *comp, EMemoConduitContext *ctxt)
 {
-	const char *uid;
+	const gchar *uid;
 	GSList *d_list = NULL;
 	ECalComponentText *description;
 	ECalComponentClassification classif;
@@ -537,9 +537,9 @@ local_record_from_comp (EMemoLocalRecord *local, ECalComponent *comp, EMemoCondu
 		struct Memo memo;
 		pi_buffer_t * record;
 #else
-		char record[0xffff];
+		gchar record[0xffff];
 #endif
-		int cat = 0;
+		gint cat = 0;
 
 #ifdef PILOT_LINK_0_12
 		record = pi_buffer_new(DLP_BUF_SIZE);
@@ -602,7 +602,7 @@ local_record_from_comp (EMemoLocalRecord *local, ECalComponent *comp, EMemoCondu
 
 static void
 local_record_from_uid (EMemoLocalRecord *local,
-		       const char *uid,
+		       const gchar *uid,
 		       EMemoConduitContext *ctxt)
 {
 	ECalComponent *comp;
@@ -636,7 +636,6 @@ local_record_from_uid (EMemoLocalRecord *local,
 	g_clear_error (&error);
 }
 
-
 static ECalComponent *
 comp_from_remote_record (GnomePilotConduitSyncAbs *conduit,
 			 GnomePilotRecord *remote,
@@ -648,8 +647,8 @@ comp_from_remote_record (GnomePilotConduitSyncAbs *conduit,
 	struct Memo memo;
 	struct icaltimetype now;
 	icaltimezone *utc_zone;
-	char *txt, *txt2, *txt3;
-	int i;
+	gchar *txt, *txt2, *txt3;
+	gint i;
 #ifdef PILOT_LINK_0_12
 	pi_buffer_t * buffer;
 #endif
@@ -694,7 +693,7 @@ comp_from_remote_record (GnomePilotConduitSyncAbs *conduit,
 		e_cal_component_set_comment_list (comp, NULL);
 		e_cal_component_set_summary(comp, NULL);
 	} else {
-		int idxToUse = -1, ntext = strlen(memo.text);
+		gint idxToUse = -1, ntext = strlen(memo.text);
 		gboolean foundNL = FALSE;
 		GSList l;
 		ECalComponentText text, sumText;
@@ -736,7 +735,6 @@ comp_from_remote_record (GnomePilotConduitSyncAbs *conduit,
 		free(txt3);
 	}
 
-
 	e_cal_component_set_transparency (comp, E_CAL_COMPONENT_TRANSP_NONE);
 
 	if (remote->secret)
@@ -755,8 +753,8 @@ static void
 check_for_slow_setting (GnomePilotConduit *c, EMemoConduitContext *ctxt)
 {
 	GnomePilotConduitStandard *conduit = GNOME_PILOT_CONDUIT_STANDARD (c);
-	int map_count;
-	const char *uri;
+	gint map_count;
+	const gchar *uri;
 
 	/* If there are no objects or objects but no log */
 	map_count = g_hash_table_size (ctxt->map->pid_map);
@@ -787,9 +785,9 @@ pre_sync (GnomePilotConduit *conduit,
 {
 	GnomePilotConduitSyncAbs *abs_conduit;
 	GList *l;
-	int len;
-	unsigned char *buf;
-	char *filename, *change_id;
+	gint len;
+	guchar *buf;
+	gchar *filename, *change_id;
 	icalcomponent *icalcomp;
 	gint num_records, add_records = 0, mod_records = 0, del_records = 0;
 #ifdef PILOT_LINK_0_12
@@ -851,7 +849,7 @@ pre_sync (GnomePilotConduit *conduit,
 
 	for (l = ctxt->changed; l != NULL; l = l->next) {
 		ECalChange *ccc = l->data;
-		const char *uid;
+		const gchar *uid;
 
 		e_cal_component_get_uid (ccc->comp, &uid);
 		if (!e_pilot_map_uid_is_archived (ctxt->map, uid)) {
@@ -891,13 +889,13 @@ pre_sync (GnomePilotConduit *conduit,
 		return -1;
 	}
 
- 	len = dlp_ReadAppBlock (dbi->pilot_socket, dbi->db_handle, 0,
+	len = dlp_ReadAppBlock (dbi->pilot_socket, dbi->db_handle, 0,
 				DLP_BUF_SIZE,
 				buffer);
 #else
-	buf = (unsigned char*)g_malloc (0xffff);
+	buf = (guchar *)g_malloc (0xffff);
 	len = dlp_ReadAppBlock (dbi->pilot_socket, dbi->db_handle, 0,
-			      (unsigned char *)buf, 0xffff);
+			      (guchar *)buf, 0xffff);
 #endif
 	if (len < 0) {
 		WARN (_("Could not read pilot's Memo application block"));
@@ -909,7 +907,7 @@ pre_sync (GnomePilotConduit *conduit,
 #ifdef PILOT_LINK_0_12
 	buf = g_new0 (unsigned char,buffer->used);
 	memcpy(buf, buffer->data, buffer->used);
- 	unpack_MemoAppInfo (&(ctxt->ai), buf, len);
+	unpack_MemoAppInfo (&(ctxt->ai), buf, len);
 	pi_buffer_free(buffer);
 #else
 	unpack_MemoAppInfo (&(ctxt->ai), buf, len);
@@ -934,15 +932,15 @@ post_sync (GnomePilotConduit *conduit,
 {
 	GList *changed;
 	gchar *filename, *change_id;
-	unsigned char *buf;
-	int dlpRetVal, len;
+	guchar *buf;
+	gint dlpRetVal, len;
 
-	buf = (unsigned char*)g_malloc (0xffff);
+	buf = (guchar *)g_malloc (0xffff);
 
 	len = pack_MemoAppInfo (&(ctxt->ai), buf, 0xffff);
 
 	dlpRetVal = dlp_WriteAppBlock (dbi->pilot_socket, dbi->db_handle,
-			      (unsigned char *)buf, len);
+			      (guchar *)buf, len);
 
 	g_free (buf);
 
@@ -954,7 +952,6 @@ post_sync (GnomePilotConduit *conduit,
 		return -1;
 	}
 
-
 	LOG (g_message ( "post_sync: Memo Conduit v.%s", CONDUIT_VERSION ));
 
 	g_free (ctxt->cfg->last_uri);
@@ -984,7 +981,7 @@ set_pilot_id (GnomePilotConduitSyncAbs *conduit,
 	      guint32 ID,
 	      EMemoConduitContext *ctxt)
 {
-	const char *uid;
+	const gchar *uid;
 
 	LOG (g_message ( "set_pilot_id: setting to %d\n", ID ));
 
@@ -999,7 +996,7 @@ set_status_cleared (GnomePilotConduitSyncAbs *conduit,
 		    EMemoLocalRecord *local,
 		    EMemoConduitContext *ctxt)
 {
-	const char *uid;
+	const gchar *uid;
 
 	LOG (g_message ( "set_status_cleared: clearing status\n" ));
 
@@ -1015,7 +1012,7 @@ for_each (GnomePilotConduitSyncAbs *conduit,
 	  EMemoConduitContext *ctxt)
 {
 	static GList *comps, *iterator;
-	static int count;
+	static gint count;
         GList *unused;
 
 	g_return_val_if_fail (local != NULL, -1);
@@ -1035,7 +1032,7 @@ for_each (GnomePilotConduitSyncAbs *conduit,
 			/* NOTE: ignore the return value, otherwise ctxt->locals
 			 * gets messed up. The calling function keeps track of
 			 * the *local variable */
-		        unused = g_list_prepend (ctxt->locals, *local);
+			unused = g_list_prepend (ctxt->locals, *local);
 			iterator = comps;
 		} else {
 			LOG (g_message ( "no events" ));
@@ -1075,7 +1072,7 @@ for_each_modified (GnomePilotConduitSyncAbs *conduit,
 		   EMemoConduitContext *ctxt)
 {
 	static GList *iterator;
-	static int count;
+	static gint count;
         GList *unused;
 
 	g_return_val_if_fail (local != NULL, 0);
@@ -1138,7 +1135,7 @@ compare (GnomePilotConduitSyncAbs *conduit,
 {
 	/* used by the quick compare */
 	GnomePilotRecord local_pilot;
-	int retval = 0;
+	gint retval = 0;
 
 	LOG (g_message ("compare: local=%s remote=%s...\n",
 			print_local (local), print_remote (remote)));
@@ -1166,8 +1163,8 @@ add_record (GnomePilotConduitSyncAbs *conduit,
 	    EMemoConduitContext *ctxt)
 {
 	ECalComponent *comp;
-	char *uid;
-	int retval = 0;
+	gchar *uid;
+	gint retval = 0;
 
 	g_return_val_if_fail (remote != NULL, -1);
 
@@ -1196,7 +1193,7 @@ replace_record (GnomePilotConduitSyncAbs *conduit,
 		EMemoConduitContext *ctxt)
 {
 	ECalComponent *new_comp;
-	int retval = 0;
+	gint retval = 0;
 
 	g_return_val_if_fail (remote != NULL, -1);
 
@@ -1219,7 +1216,7 @@ delete_record (GnomePilotConduitSyncAbs *conduit,
 	       EMemoLocalRecord *local,
 	       EMemoConduitContext *ctxt)
 {
-	const char *uid;
+	const gchar *uid;
 
 	g_return_val_if_fail (local != NULL, -1);
 	g_return_val_if_fail (local->comp != NULL, -1);
@@ -1241,8 +1238,8 @@ archive_record (GnomePilotConduitSyncAbs *conduit,
 		gboolean archive,
 		EMemoConduitContext *ctxt)
 {
-	const char *uid;
-	int retval = 0;
+	const gchar *uid;
+	gint retval = 0;
 
 	g_return_val_if_fail (local != NULL, -1);
 
@@ -1260,7 +1257,7 @@ match (GnomePilotConduitSyncAbs *conduit,
        EMemoLocalRecord **local,
        EMemoConduitContext *ctxt)
 {
-	const char *uid;
+	const gchar *uid;
 
 	LOG (g_message ("match: looking for local copy of %s\n",
 			print_remote (remote)));
@@ -1382,7 +1379,7 @@ conduit_get_gpilot_conduit (guint32 pilot_id)
 
 	LOG (g_message ( "in memo's conduit_get_gpilot_conduit\n" ));
 
-	retval = gnome_pilot_conduit_sync_abs_new ("MemoDB", 0x6D656D6F);
+	retval = gnome_pilot_conduit_sync_abs_new ((gchar *)"MemoDB", 0x6D656D6F);
 	g_assert (retval != NULL);
 
 	ctxt = e_memo_context_new (pilot_id);
@@ -1391,22 +1388,22 @@ conduit_get_gpilot_conduit (guint32 pilot_id)
 	g_signal_connect (retval, "pre_sync", G_CALLBACK (pre_sync), ctxt);
 	g_signal_connect (retval, "post_sync", G_CALLBACK (post_sync), ctxt);
 
-  	g_signal_connect (retval, "set_pilot_id", G_CALLBACK (set_pilot_id), ctxt);
-  	g_signal_connect (retval, "set_status_cleared", G_CALLBACK (set_status_cleared), ctxt);
+	g_signal_connect (retval, "set_pilot_id", G_CALLBACK (set_pilot_id), ctxt);
+	g_signal_connect (retval, "set_status_cleared", G_CALLBACK (set_status_cleared), ctxt);
 
-  	g_signal_connect (retval, "for_each", G_CALLBACK (for_each), ctxt);
-  	g_signal_connect (retval, "for_each_modified", G_CALLBACK (for_each_modified), ctxt);
-  	g_signal_connect (retval, "compare", G_CALLBACK (compare), ctxt);
+	g_signal_connect (retval, "for_each", G_CALLBACK (for_each), ctxt);
+	g_signal_connect (retval, "for_each_modified", G_CALLBACK (for_each_modified), ctxt);
+	g_signal_connect (retval, "compare", G_CALLBACK (compare), ctxt);
 
-  	g_signal_connect (retval, "add_record", G_CALLBACK (add_record), ctxt);
-  	g_signal_connect (retval, "replace_record", G_CALLBACK (replace_record), ctxt);
-  	g_signal_connect (retval, "delete_record", G_CALLBACK (delete_record), ctxt);
-  	g_signal_connect (retval, "archive_record", G_CALLBACK (archive_record), ctxt);
+	g_signal_connect (retval, "add_record", G_CALLBACK (add_record), ctxt);
+	g_signal_connect (retval, "replace_record", G_CALLBACK (replace_record), ctxt);
+	g_signal_connect (retval, "delete_record", G_CALLBACK (delete_record), ctxt);
+	g_signal_connect (retval, "archive_record", G_CALLBACK (archive_record), ctxt);
 
-  	g_signal_connect (retval, "match", G_CALLBACK (match), ctxt);
-  	g_signal_connect (retval, "free_match", G_CALLBACK (free_match), ctxt);
+	g_signal_connect (retval, "match", G_CALLBACK (match), ctxt);
+	g_signal_connect (retval, "free_match", G_CALLBACK (free_match), ctxt);
 
-  	g_signal_connect (retval, "prepare", G_CALLBACK (prepare), ctxt);
+	g_signal_connect (retval, "prepare", G_CALLBACK (prepare), ctxt);
 
 	/* Gui Settings */
 	g_signal_connect (retval, "create_settings_window", G_CALLBACK (create_settings_window), ctxt);
