@@ -66,8 +66,6 @@ cal_comp_util_add_exdate (ECalComponent *comp, time_t t, icaltimezone *zone)
 	e_cal_component_free_exdate_list (list);
 }
 
-
-
 /* Returns TRUE if the TZIDs are equivalent, i.e. both NULL or the same. */
 static gboolean
 e_cal_component_compare_tzid (const gchar *tzid1, const gchar *tzid2)
@@ -278,12 +276,12 @@ is_icalcomp_on_the_server (icalcomponent *icalcomp, ECal *client)
  * cal_comp_event_new_with_defaults:
  *
  * Creates a new VEVENT component and adds any default alarms to it as set in
- * the program's configuration values.
+ * the program's configuration values, but only if not the all_day event.
  *
  * Return value: A newly-created calendar component.
  **/
 ECalComponent *
-cal_comp_event_new_with_defaults (ECal *client)
+cal_comp_event_new_with_defaults (ECal *client, gboolean all_day)
 {
 	icalcomponent *icalcomp;
 	ECalComponent *comp;
@@ -303,7 +301,7 @@ cal_comp_event_new_with_defaults (ECal *client)
 		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_EVENT);
 	}
 
-	if (!calendar_config_get_use_default_reminder ())
+	if (all_day || !calendar_config_get_use_default_reminder ())
 		return comp;
 
 	interval = calendar_config_get_default_reminder_interval ();
@@ -361,7 +359,7 @@ cal_comp_event_new_with_current_time (ECal *client, gboolean all_day)
 	ECalComponentDateTime dt;
 	icaltimezone *zone;
 
-	comp = cal_comp_event_new_with_defaults (client);
+	comp = cal_comp_event_new_with_defaults (client, all_day);
 
 	g_return_val_if_fail (comp, NULL);
 
