@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -324,7 +324,7 @@ event_editor_constructor (GType type,
 			event_page_show_options (priv->event_page);
 
 		comp_editor_set_group_item (editor, TRUE);
-  		if (!((flags & COMP_EDITOR_USER_ORG) || (flags & COMP_EDITOR_DELEGATE)|| (flags & COMP_EDITOR_NEW_ITEM))) {
+		if (!((flags & COMP_EDITOR_USER_ORG) || (flags & COMP_EDITOR_DELEGATE)|| (flags & COMP_EDITOR_NEW_ITEM))) {
 			GtkAction *action;
 
 			action = comp_editor_get_action (editor, "free-busy");
@@ -346,7 +346,7 @@ event_editor_dispose (GObject *object)
 	priv = EVENT_EDITOR_GET_PRIVATE (object);
 
 	if (priv->event_page) {
- 		g_object_unref (priv->event_page);
+		g_object_unref (priv->event_page);
 		priv->event_page = NULL;
 	}
 
@@ -463,7 +463,7 @@ static void
 event_editor_init (EventEditor *ee)
 {
 	CompEditor *editor = COMP_EDITOR (ee);
-	GtkUIManager *manager;
+	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
 	GtkAction *action;
 	GError *error = NULL;
@@ -486,9 +486,9 @@ event_editor_init (EventEditor *ee)
 		action_group, meeting_entries,
 		G_N_ELEMENTS (meeting_entries), ee);
 
-	manager = comp_editor_get_ui_manager (editor);
-	gtk_ui_manager_add_ui_from_string (manager, ui, -1, &error);
-	e_plugin_ui_register_manager ("event-editor", manager, ee);
+	ui_manager = comp_editor_get_ui_manager (editor);
+	gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, &error);
+	e_plugin_ui_register_manager ("event-editor", ui_manager, ee);
 
 	if (error != NULL) {
 		g_critical ("%s: %s", G_STRFUNC, error->message);
@@ -512,8 +512,6 @@ event_editor_init (EventEditor *ee)
 	g_signal_connect_swapped (
 		ee->priv->model, "row_deleted",
 		G_CALLBACK (event_editor_model_changed_cb), ee);
-
-	gtk_window_set_default_size (GTK_WINDOW (ee), 300, 225);
 }
 
 static void
@@ -553,8 +551,8 @@ event_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 	/* Set up the attendees */
 	if (attendees != NULL) {
 		GSList *l;
-		int row;
-		char *user_email;
+		gint row;
+		gchar *user_email;
 		user_email = itip_get_comp_attendee (comp, client);
 
 		if (!priv->meeting_shown) {
@@ -693,7 +691,7 @@ event_editor_show_meeting (EventEditor *ee)
 
 		ee->priv->meeting_shown = TRUE;
 
- 		comp_editor_set_changed (editor, FALSE);
+		comp_editor_set_changed (editor, FALSE);
 		comp_editor_set_needs_send (editor, TRUE);
 	}
 
