@@ -10,12 +10,12 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
  *		Mike Kestner  <mkestner@ximian.com>
- * 	    JP Rosevear  <jpr@ximian.com>
+ *	    JP Rosevear  <jpr@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
@@ -31,7 +31,6 @@
 #include <bonobo/bonobo-widget.h>
 #include <bonobo/bonobo-exception.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-util.h>
 #include <libebook/e-book.h>
 #include <libebook/e-vcard.h>
 #include <libecal/e-cal-component.h>
@@ -65,11 +64,12 @@ static guint e_meeting_list_view_signals[LAST_SIGNAL] = { 0 };
 
 static void name_selector_dialog_close_cb (ENameSelectorDialog *dialog, gint response, gpointer data);
 
-static char *sections[] = {N_("Chair Persons"),
-			   N_("Required Participants"),
-			   N_("Optional Participants"),
-			   N_("Resources"),
-			   NULL};
+static const gchar *sections[] = {N_("Chair Persons"),
+				  N_("Required Participants"),
+				  N_("Optional Participants"),
+				  N_("Resources"),
+				  NULL};
+
 static icalparameter_role roles[] = {ICAL_ROLE_CHAIR,
 				     ICAL_ROLE_REQPARTICIPANT,
 				     ICAL_ROLE_OPTPARTICIPANT,
@@ -97,7 +97,7 @@ e_meeting_list_view_finalize (GObject *obj)
 	g_free (priv);
 
 	if (G_OBJECT_CLASS (e_meeting_list_view_parent_class)->finalize)
- 		(* G_OBJECT_CLASS (e_meeting_list_view_parent_class)->finalize) (obj);
+		(* G_OBJECT_CLASS (e_meeting_list_view_parent_class)->finalize) (obj);
 }
 
 static void
@@ -120,9 +120,8 @@ e_meeting_list_view_class_init (EMeetingListViewClass *klass)
 			      G_TYPE_POINTER);
 }
 
-
 static void
-add_section (ENameSelector *name_selector, const char *name)
+add_section (ENameSelector *name_selector, const gchar *name)
 {
 	ENameSelectorModel *name_selector_model;
 
@@ -150,7 +149,7 @@ e_meeting_list_view_init (EMeetingListView *view)
 
 	name_selector_dialog = e_name_selector_peek_dialog (view->priv->name_selector);
 	gtk_window_set_title (GTK_WINDOW (name_selector_dialog), _("Attendees"));
- 	g_signal_connect (name_selector_dialog, "response",
+	g_signal_connect (name_selector_dialog, "response",
 			  G_CALLBACK (name_selector_dialog_close_cb), view);
 
 }
@@ -160,11 +159,11 @@ get_type_strings (void)
 {
 	GList *strings = NULL;
 
-	strings = g_list_append (strings, (char*) _("Individual"));
-        strings = g_list_append (strings, (char*) _("Group"));
-        strings = g_list_append (strings, (char*) _("Resource"));
-        strings = g_list_append (strings, (char*) _("Room"));
-        strings = g_list_append (strings, (char*) _("Unknown"));
+	strings = g_list_append (strings, (gchar *) _("Individual"));
+        strings = g_list_append (strings, (gchar *) _("Group"));
+        strings = g_list_append (strings, (gchar *) _("Resource"));
+        strings = g_list_append (strings, (gchar *) _("Room"));
+        strings = g_list_append (strings, (gchar *) _("Unknown"));
 
 	return strings;
 }
@@ -174,11 +173,11 @@ get_role_strings (void)
 {
 	GList *strings = NULL;
 
-	strings = g_list_append (strings, (char*) _("Chair"));
-	strings = g_list_append (strings, (char*) _("Required Participant"));
-	strings = g_list_append (strings, (char*) _("Optional Participant"));
-	strings = g_list_append (strings, (char*) _("Non-Participant"));
-	strings = g_list_append (strings, (char*) _("Unknown"));
+	strings = g_list_append (strings, (gchar *) _("Chair"));
+	strings = g_list_append (strings, (gchar *) _("Required Participant"));
+	strings = g_list_append (strings, (gchar *) _("Optional Participant"));
+	strings = g_list_append (strings, (gchar *) _("Non-Participant"));
+	strings = g_list_append (strings, (gchar *) _("Unknown"));
 
 	return strings;
 }
@@ -188,8 +187,8 @@ get_rsvp_strings (void)
 {
 	GList *strings = NULL;
 
-	strings = g_list_append (strings, (char*) _("Yes"));
-	strings = g_list_append (strings, (char*) _("No"));
+	strings = g_list_append (strings, (gchar *) _("Yes"));
+	strings = g_list_append (strings, (gchar *) _("No"));
 
 	return strings;
 }
@@ -199,11 +198,11 @@ get_status_strings (void)
 {
 	GList *strings = NULL;
 
-	strings = g_list_append (strings, (char*) _("Needs Action"));
-	strings = g_list_append (strings, (char*) _("Accepted"));
-	strings = g_list_append (strings, (char*) _("Declined"));
-	strings = g_list_append (strings, (char*) _("Tentative"));
-	strings = g_list_append (strings, (char*) _("Delegated"));
+	strings = g_list_append (strings, (gchar *) _("Needs Action"));
+	strings = g_list_append (strings, (gchar *) _("Accepted"));
+	strings = g_list_append (strings, (gchar *) _("Declined"));
+	strings = g_list_append (strings, (gchar *) _("Tentative"));
+	strings = g_list_append (strings, (gchar *) _("Delegated"));
 
 	return strings;
 }
@@ -213,7 +212,7 @@ value_edited (GtkTreeView *view, gint col, const gchar *path, const gchar *text)
 {
 	EMeetingStore *model = E_MEETING_STORE (gtk_tree_view_get_model (view));
 	GtkTreePath *treepath = gtk_tree_path_new_from_string (path);
-	int row = gtk_tree_path_get_indices (treepath)[0];
+	gint row = gtk_tree_path_get_indices (treepath)[0];
 
 	e_meeting_store_set_value (model, row, col, text);
 	gtk_tree_path_free (treepath);
@@ -264,7 +263,7 @@ e_meeting_list_view_remove_attendee_from_name_selector (EMeetingListView *view,
 	GList             *destinations, *l;
 	EDestinationStore *destination_store;
 	ENameSelectorModel *name_selector_model;
-	const char *madd = NULL;
+	const gchar *madd = NULL;
 	EMeetingListViewPrivate *priv;
 	guint i = 1;
 
@@ -278,10 +277,9 @@ e_meeting_list_view_remove_attendee_from_name_selector (EMeetingListView *view,
 	madd = itip_strip_mailto (e_meeting_attendee_get_address (ma));
 
 	for (l = destinations; l; l = g_list_next (l)) {
-		const char *attendee = NULL;
+		const gchar *attendee = NULL;
 		EDestination *des = l->data;
 
-
 		if (e_destination_is_evolution_list (des)) {
 			GList *l, *dl;
 
@@ -297,10 +295,8 @@ e_meeting_list_view_remove_attendee_from_name_selector (EMeetingListView *view,
 			}
 		} else {
 			attendee = e_destination_get_email (des);
-
 			if (madd && attendee && g_str_equal (madd, attendee)) {
-			attendee = e_destination_get_email (des);
-			e_destination_store_remove_destination (destination_store, des);
+				e_destination_store_remove_destination (destination_store, des);
 			}
 		}
 	}
@@ -308,12 +304,55 @@ e_meeting_list_view_remove_attendee_from_name_selector (EMeetingListView *view,
 	g_list_free (destinations);
 }
 
+void
+e_meeting_list_view_remove_all_attendees_from_name_selector (EMeetingListView *view)
+{
+	ENameSelectorModel *name_selector_model;
+	EMeetingListViewPrivate *priv;
+	guint i;
+
+	priv = view->priv;
+
+	name_selector_model = e_name_selector_peek_model (priv->name_selector);
+
+	for (i = 0; sections[i] != NULL; i++) {
+		EDestinationStore *destination_store = NULL;
+		GList             *destinations = NULL, *l = NULL;
+
+		e_name_selector_model_peek_section (name_selector_model, sections[i],
+						    NULL, &destination_store);
+		if (!destination_store) {
+			g_warning ("destination store is NULL\n");
+			continue;
+		}
+
+		destinations = e_destination_store_list_destinations (destination_store);
+		for (l = destinations; l; l = g_list_next (l)) {
+			EDestination *des = l->data;
+
+			if (e_destination_is_evolution_list (des)) {
+				GList *m, *dl;
+
+				dl = (GList *)e_destination_list_get_dests (des);
+
+				for (m = dl; m; m = m->next) {
+					g_object_unref (m->data);
+					m = g_list_remove (m, l->data);
+				}
+			} else {
+				e_destination_store_remove_destination (destination_store, des);
+			}
+		}
+		g_list_free (destinations);
+	}
+}
+
 static void
 attendee_edited_cb (GtkCellRenderer *renderer, const gchar *path, GList *addresses, GList *names, GtkTreeView *view)
 {
 	EMeetingStore *model = E_MEETING_STORE (gtk_tree_view_get_model (view));
 	GtkTreePath *treepath = gtk_tree_path_new_from_string (path);
-	int row = gtk_tree_path_get_indices (treepath)[0];
+	gint row = gtk_tree_path_get_indices (treepath)[0];
 	EMeetingAttendee *existing_attendee;
 	gboolean removed = FALSE, address_changed = FALSE;
 
@@ -324,7 +363,7 @@ attendee_edited_cb (GtkCellRenderer *renderer, const gchar *path, GList *address
 		GList *l, *m;
 
 		for (l = addresses, m = names; l && m; l = l->next, m = m->next) {
-			char *name = m->data, *email = l->data;
+			gchar *name = m->data, *email = l->data;
 
 			if (!((name && *name) || (email && *email)))
 					continue;
@@ -333,7 +372,7 @@ attendee_edited_cb (GtkCellRenderer *renderer, const gchar *path, GList *address
 				continue;
 
 			attendee = e_meeting_store_add_attendee_with_defaults (model);
-			e_meeting_attendee_set_address (attendee, g_strdup_printf ("MAILTO:%s", (char *)l->data));
+			e_meeting_attendee_set_address (attendee, g_strdup_printf ("MAILTO:%s", (gchar *)l->data));
 			e_meeting_attendee_set_cn (attendee, g_strdup (m->data));
 			if (existing_attendee) {
 				/* FIXME Should we copy anything else? */
@@ -354,8 +393,8 @@ attendee_edited_cb (GtkCellRenderer *renderer, const gchar *path, GList *address
 		}
 
 	} else if (g_list_length (addresses) == 1) {
-		char *name = names->data, *email = addresses->data;
-		int existing_row;
+		gchar *name = names->data, *email = addresses->data;
+		gint existing_row;
 
 		if (!((name && *name) || (email && *email)) || ((e_meeting_store_find_attendee (model, email, &existing_row) != NULL) && existing_row != row)){
 			if (existing_attendee) {
@@ -389,7 +428,7 @@ attendee_edited_cb (GtkCellRenderer *renderer, const gchar *path, GList *address
 		}
 	} else {
 		if (existing_attendee) {
-			const char *address = e_meeting_attendee_get_address (existing_attendee);
+			const gchar *address = e_meeting_attendee_get_address (existing_attendee);
 
 			if (!(address && *address)) {
 				removed = TRUE;
@@ -415,7 +454,7 @@ attendee_editing_canceled_cb (GtkCellRenderer *renderer, GtkTreeView *view)
 	EMeetingStore *model = E_MEETING_STORE (gtk_tree_view_get_model (view));
 	GtkTreePath *path;
 	EMeetingAttendee *existing_attendee;
-	int row;
+	gint row;
 
 	/* This is for newly added attendees when the editing is cancelled */
 	gtk_tree_view_get_cursor (view, &path, NULL);
@@ -432,7 +471,6 @@ attendee_editing_canceled_cb (GtkCellRenderer *renderer, GtkTreeView *view)
 	gtk_tree_path_free (path);
 }
 
-
 static void
 type_edited_cb (GtkCellRenderer *renderer, const gchar *path, const gchar *text, GtkTreeView *view)
 {
@@ -493,7 +531,7 @@ build_table (EMeetingListView *lview)
 	EMeetingListViewPrivate *priv;
 	GHashTable *edit_table;
 	GtkTreeViewColumn *col;
-	int pos;
+	gint pos;
 
 	priv = lview->priv;
 	edit_table = priv->renderers;
@@ -512,6 +550,7 @@ build_table (EMeetingListView *lview)
 	col = gtk_tree_view_get_column (view, pos -1);
 	gtk_tree_view_column_set_resizable (col, TRUE);
 	gtk_tree_view_column_set_reorderable(col, TRUE);
+	gtk_tree_view_column_set_expand (col, TRUE);
 	g_object_set (col, "min-width", 50, NULL);
 	g_object_set_data (G_OBJECT (col), "mtg-store-col", GINT_TO_POINTER (E_MEETING_STORE_ATTENDEE_COL));
 	g_signal_connect (renderer, "cell_edited", G_CALLBACK (attendee_edited_cb), view);
@@ -576,7 +615,7 @@ static void
 change_edit_cols_for_user (gpointer key, gpointer value, gpointer user_data)
 {
        GtkCellRenderer *renderer = (GtkCellRenderer *) value;
-       int key_val = GPOINTER_TO_INT (key);
+       gint key_val = GPOINTER_TO_INT (key);
        switch (key_val)
        {
                case E_MEETING_STORE_ATTENDEE_COL:
@@ -610,7 +649,7 @@ row_activated_cb (GtkTreeSelection *selection, EMeetingListView *view)
 {
        EMeetingAttendee *existing_attendee;
        EMeetingListViewPrivate *priv;
-       int row;
+       gint row;
        EMeetingAttendeeEditLevel el;
        gint  edit_level;
        GtkTreeModel *model;
@@ -619,7 +658,6 @@ row_activated_cb (GtkTreeSelection *selection, EMeetingListView *view)
 
        priv = view->priv;
 
-
        if (!(paths = gtk_tree_selection_get_selected_rows (selection, &model)))
                return;
        if (g_list_length (paths) > 1)
@@ -652,7 +690,6 @@ row_activated_cb (GtkTreeSelection *selection, EMeetingListView *view)
 
 }
 
-
 EMeetingListView *
 e_meeting_list_view_new (EMeetingStore *store)
 {
@@ -734,7 +771,7 @@ process_section (EMeetingListView *view, GList *destinations, icalparameter_role
 				ENameSelectorDialog *dialog;
 				EContactStore *c_store;
 				GList *books, *l;
-				char *uri = e_contact_get (contact, E_CONTACT_BOOK_URI);
+				gchar *uri = e_contact_get (contact, E_CONTACT_BOOK_URI);
 
 				dialog = e_name_selector_peek_dialog (view->priv->name_selector);
 				c_store = dialog->name_selector_model->contact_store;
@@ -751,11 +788,11 @@ process_section (EMeetingListView *view, GList *destinations, icalparameter_role
 				if (book) {
 					GList *contacts;
 					EContact *n_con = NULL;
-					char *qu;
+					gchar *qu;
 					EBookQuery *query;
 
 					qu = g_strdup_printf ("(is \"full_name\" \"%s\")",
-							(char *) e_contact_get (contact, E_CONTACT_FULL_NAME));
+							(gchar *) e_contact_get (contact, E_CONTACT_FULL_NAME));
 					query = e_book_query_from_string (qu);
 
 					if (!e_book_get_contacts (book, query, &contacts, NULL)) {
@@ -787,8 +824,8 @@ process_section (EMeetingListView *view, GList *destinations, icalparameter_role
 		for (l = list_dests; l; l = l->next) {
 			EDestination *dest = l->data;
 			EContact *contact;
-			const char *name, *attendee = NULL;
-			char *attr = NULL, *fburi = NULL;
+			const gchar *name, *attendee = NULL;
+			gchar *attr = NULL, *fburi = NULL;
 
 			name = e_destination_get_name (dest);
 
@@ -821,7 +858,6 @@ process_section (EMeetingListView *view, GList *destinations, icalparameter_role
 			if (contact)
 				fburi = e_contact_get (contact, E_CONTACT_FREEBUSY_URL);
 
-
 			if (e_meeting_store_find_attendee (priv->store, attendee, NULL) == NULL) {
 				EMeetingAttendee *ia = e_meeting_store_add_attendee_with_defaults (priv->store);
 
@@ -865,8 +901,8 @@ name_selector_dialog_close_cb (ENameSelectorDialog *dialog, gint response, gpoin
 	ENameSelectorModel *name_selector_model;
 	EMeetingStore *store;
 	const GPtrArray *attendees;
-	int i;
-	GSList 		  *la = NULL, *l;
+	gint i;
+	GSList		  *la = NULL, *l;
 
 	name_selector_model = e_name_selector_peek_model (view->priv->name_selector);
 	store = E_MEETING_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (view)));
@@ -894,13 +930,17 @@ name_selector_dialog_close_cb (ENameSelectorDialog *dialog, gint response, gpoin
 	/* remove the deleted attendees from name selector */
 	for (l = la; l != NULL; l = l->next) {
 		EMeetingAttendee *ma = NULL;
-		const char *email = l->data;
-		int i;
+		const gchar *email = l->data;
+		gint i;
 
 		ma = e_meeting_store_find_attendee (store, email, &i);
 
-		if (ma)
-			e_meeting_store_remove_attendee (store, ma);
+		if (ma) {
+			if (e_meeting_attendee_get_edit_level (ma) != E_MEETING_ATTENDEE_EDIT_FULL)
+				g_warning ("Not enough rights to delete attendee: %s\n", e_meeting_attendee_get_address (ma));
+			else
+				e_meeting_store_remove_attendee (store, ma);
+		}
 	}
 
 	g_slist_free (la);
@@ -957,4 +997,3 @@ e_meeting_list_view_set_name_selector (EMeetingListView *lview, ENameSelector *n
 	priv->name_selector = g_object_ref (name_selector);
 }
 
-
