@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -46,13 +46,13 @@ static void e_week_view_event_item_set_property	(GObject	 *object,
 static void e_week_view_event_item_update	(GnomeCanvasItem *item,
 						 double		 *affine,
 						 ArtSVP		 *clip_path,
-						 int		  flags);
+						 gint		  flags);
 static void e_week_view_event_item_draw		(GnomeCanvasItem *item,
 						 GdkDrawable	 *drawable,
-						 int		  x,
-						 int		  y,
-						 int		  width,
-						 int		  height);
+						 gint		  x,
+						 gint		  y,
+						 gint		  width,
+						 gint		  height);
 static void e_week_view_draw_time		(EWeekView	*week_view,
 						 GdkDrawable	*drawable,
 						 gint		 time_x,
@@ -74,8 +74,8 @@ static void e_week_view_event_item_draw_triangle (EWeekViewEventItem *wveitem,
 static double e_week_view_event_item_point	(GnomeCanvasItem *item,
 						 double		  x,
 						 double		  y,
-						 int		  cx,
-						 int		  cy,
+						 gint		  cx,
+						 gint		  cy,
 						 GnomeCanvasItem **actual_item);
 static gint e_week_view_event_item_event	(GnomeCanvasItem *item,
 						 GdkEvent	 *event);
@@ -89,7 +89,6 @@ static ECalendarViewPosition e_week_view_event_item_get_position (EWeekViewEvent
 							      gdouble x,
 							      gdouble y);
 
-
 /* The arguments we take */
 enum {
 	PROP_0,
@@ -139,7 +138,6 @@ e_week_view_event_item_class_init (EWeekViewEventItemClass *class)
 			G_PARAM_WRITABLE));
 }
 
-
 static void
 e_week_view_event_item_init (EWeekViewEventItem *wveitem)
 {
@@ -147,7 +145,6 @@ e_week_view_event_item_init (EWeekViewEventItem *wveitem)
 	wveitem->span_num = -1;
 }
 
-
 static void
 e_week_view_event_item_set_property (GObject *object,
                                      guint property_id,
@@ -174,12 +171,11 @@ e_week_view_event_item_set_property (GObject *object,
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 }
 
-
 static void
 e_week_view_event_item_update (GnomeCanvasItem *item,
 			       double	       *affine,
 			       ArtSVP	       *clip_path,
-			       int	        flags)
+			       gint		flags)
 {
 	EWeekViewEventItem *wveitem;
 	EWeekView *week_view;
@@ -226,10 +222,10 @@ e_week_view_event_item_update (GnomeCanvasItem *item,
 static void
 e_week_view_event_item_draw (GnomeCanvasItem  *canvas_item,
 			     GdkDrawable      *drawable,
-			     int	       x,
-			     int	       y,
-			     int	       width,
-			     int	       height)
+			     gint	       x,
+			     gint	       y,
+			     gint	       width,
+			     gint	       height)
 {
 	EWeekViewEventItem *wveitem;
 	EWeekView *week_view;
@@ -636,7 +632,8 @@ e_week_view_draw_time	(EWeekView	*week_view,
 	GdkGC *gc;
 	gint hour_to_display, suffix_width;
 	gint time_y_normal_font, time_y_small_font;
-	gchar buffer[128], *suffix;
+	const gchar *suffix;
+	gchar buffer[128];
 	PangoLayout *layout;
 	PangoFontDescription *small_font_desc;
 
@@ -719,7 +716,6 @@ e_week_view_draw_time	(EWeekView	*week_view,
 	g_object_unref (layout);
 }
 
-
 static void
 e_week_view_event_item_draw_icons (EWeekViewEventItem *wveitem,
 				   GdkDrawable        *drawable,
@@ -827,11 +823,11 @@ e_week_view_event_item_draw_icons (EWeekViewEventItem *wveitem,
 
 	/* draw categories icons */
 	for (elem = categories_list; elem; elem = elem->next) {
-		char *category;
+		gchar *category;
 		GdkPixmap *pixmap = NULL;
 		GdkBitmap *mask = NULL;
 
-		category = (char *) elem->data;
+		category = (gchar *) elem->data;
 		if (!e_categories_config_get_icon_for (category, &pixmap, &mask))
 			continue;
 
@@ -858,7 +854,6 @@ e_week_view_event_item_draw_icons (EWeekViewEventItem *wveitem,
 	gdk_gc_set_clip_mask (gc, NULL);
 }
 
-
 /* This draws a little triangle to indicate that an event extends past
    the days visible on screen. */
 static void
@@ -921,7 +916,6 @@ e_week_view_event_item_draw_triangle (EWeekViewEventItem *wveitem,
 	cairo_save (cr);
 	gdk_cairo_set_source_color (cr, &week_view->colors[E_WEEK_VIEW_COLOR_EVENT_BORDER]);
 
-
 	/* If the height is odd we can use the same central point for both
 	   lines. If it is even we use different end-points. */
 	c1 = c2 = y + (h / 2);
@@ -943,14 +937,13 @@ e_week_view_event_item_draw_triangle (EWeekViewEventItem *wveitem,
    This is needed so that we get button/motion events. */
 static double
 e_week_view_event_item_point (GnomeCanvasItem *item, double x, double y,
-			      int cx, int cy,
+			      gint cx, gint cy,
 			      GnomeCanvasItem **actual_item)
 {
 	*actual_item = item;
 	return 0.0;
 }
 
-
 static gint
 e_week_view_event_item_event (GnomeCanvasItem *item, GdkEvent *event)
 {
@@ -974,7 +967,6 @@ e_week_view_event_item_event (GnomeCanvasItem *item, GdkEvent *event)
 	return FALSE;
 }
 
-
 static gboolean
 e_week_view_event_item_button_press (EWeekViewEventItem *wveitem,
 				     GdkEvent		*bevent)
@@ -1044,7 +1036,6 @@ e_week_view_event_item_button_press (EWeekViewEventItem *wveitem,
 	return FALSE;
 }
 
-
 static gboolean
 e_week_view_event_item_button_release (EWeekViewEventItem *wveitem,
 				       GdkEvent		  *event)
@@ -1108,7 +1099,6 @@ e_week_view_event_item_double_click (EWeekViewEventItem *wveitem,
 	return TRUE;
 }
 
-
 static ECalendarViewPosition
 e_week_view_event_item_get_position (EWeekViewEventItem *wveitem,
 				     gdouble x,
