@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -43,21 +43,21 @@
 #include "evolution-shell-component-utils.h"
 #include "e-util/e-menu.h"
 #include "e-cal-menu.h"
+#include "e-cal-component-preview.h"
 #include "e-util/e-menu.h"
 #include "itip-utils.h"
 
 #define FIXED_MARGIN                            .05
 
-
 static void tasks_control_activate_cb		(BonoboControl		*control,
 						 gboolean		 activate,
 						 gpointer		 user_data);
 static void tasks_control_open_task_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_new_task_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_cut_cmd               (BonoboUIComponent      *uic,
 						 gpointer                data,
 						 const gchar            *path);
@@ -69,38 +69,46 @@ static void tasks_control_paste_cmd             (BonoboUIComponent      *uic,
 						 const gchar            *path);
 static void tasks_control_delete_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_complete_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_purge_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_print_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_print_preview_cmd	(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path);
+						 const gchar		*path);
 static void tasks_control_assign_cmd           (BonoboUIComponent      *uic,
                                                 gpointer               data,
-                                                const char             *path);
+                                                const gchar             *path);
 
 static void tasks_control_forward_cmd          (BonoboUIComponent      *uic,
                                                 gpointer               data,
-                                                const char             *path);
+                                                const gchar             *path);
 
 static void tasks_control_view_preview	       (BonoboUIComponent *uic,
-						const char *path,
+						const gchar *path,
 						Bonobo_UIComponent_EventType type,
-						const char *state,
-						void *data);
+						const gchar *state,
+						gpointer data);
+
+struct focus_changed_data {
+	BonoboControl *control;
+	ETasks *tasks;
+};
+
+static gboolean tasks_control_focus_changed (GtkWidget *widget, GdkEventFocus *event, struct focus_changed_data *fc_data);
 
 BonoboControl *
 tasks_control_new (void)
 {
 	BonoboControl *control;
-	GtkWidget *tasks;
+	GtkWidget *tasks, *preview;
+	struct focus_changed_data *fc_data;
 
 	tasks = e_tasks_new ();
 	if (!tasks)
@@ -116,10 +124,18 @@ tasks_control_new (void)
 
 	g_signal_connect (control, "activate", G_CALLBACK (tasks_control_activate_cb), tasks);
 
+	fc_data = g_new0 (struct focus_changed_data, 1);
+	fc_data->control = control;
+	fc_data->tasks = E_TASKS (tasks);
+
+	preview = e_cal_component_preview_get_html (E_CAL_COMPONENT_PREVIEW (e_tasks_get_preview (fc_data->tasks)));
+	g_object_set_data_full (G_OBJECT (preview), "tasks-ctrl-fc-data", fc_data, g_free);
+	g_signal_connect (preview, "focus-in-event", G_CALLBACK (tasks_control_focus_changed), fc_data);
+	g_signal_connect (preview, "focus-out-event", G_CALLBACK (tasks_control_focus_changed), fc_data);
+
 	return control;
 }
 
-
 static void
 tasks_control_activate_cb		(BonoboControl		*control,
 					 gboolean		 activate,
@@ -136,7 +152,7 @@ tasks_control_activate_cb		(BonoboControl		*control,
 }
 
 struct _tasks_sensitize_item {
-	char *command;
+	const gchar *command;
 	guint32 enable;
 };
 
@@ -144,7 +160,7 @@ static void
 sensitize_items(BonoboUIComponent *uic, struct _tasks_sensitize_item *items, guint32 mask)
 {
 	while (items->command) {
-		char command[32];
+		gchar command[32];
 
 		if (strlen(items->command)>=21) {
 			g_warning ("Size more than 21: %s\n", items->command);
@@ -160,11 +176,13 @@ sensitize_items(BonoboUIComponent *uic, struct _tasks_sensitize_item *items, gui
 	}
 }
 
+#define E_CAL_TASKS_PREVIEW_ACTIVE (1<<31)
+
 static struct _tasks_sensitize_item tasks_sensitize_table[] = {
 	{ "TasksOpenTask", E_CAL_MENU_SELECT_ONE },
-	{ "TasksCut", E_CAL_MENU_SELECT_ANY | E_CAL_MENU_SELECT_EDITABLE },
+	{ "TasksCut", E_CAL_MENU_SELECT_ANY | E_CAL_MENU_SELECT_EDITABLE | E_CAL_TASKS_PREVIEW_ACTIVE },
 	{ "TasksCopy", E_CAL_MENU_SELECT_ANY },
-	{ "TasksPaste", E_CAL_MENU_SELECT_EDITABLE },
+	{ "TasksPaste", E_CAL_MENU_SELECT_EDITABLE | E_CAL_TASKS_PREVIEW_ACTIVE },
 	{ "TasksDelete", E_CAL_MENU_SELECT_ANY | E_CAL_MENU_SELECT_EDITABLE },
 	{ "TasksMarkComplete", E_CAL_MENU_SELECT_ANY | E_CAL_MENU_SELECT_EDITABLE | E_CAL_MENU_SELECT_NOTCOMPLETE},
 	{ "TasksPurge",  E_CAL_MENU_SELECT_EDITABLE },
@@ -177,7 +195,7 @@ static struct _tasks_sensitize_item tasks_sensitize_table[] = {
  * selected tasks.
  */
 void
-tasks_control_sensitize_commands (BonoboControl *control, ETasks *tasks, int n_selected)
+tasks_control_sensitize_commands (BonoboControl *control, ETasks *tasks, gint n_selected)
 {
 	BonoboUIComponent *uic;
 	gboolean read_only = TRUE;
@@ -188,6 +206,7 @@ tasks_control_sensitize_commands (BonoboControl *control, ETasks *tasks, int n_s
 	GPtrArray *events;
 	GSList *selected = NULL, *l = NULL;
 	ECalendarTable *cal_table;
+	GtkWidget *preview;
 
 	uic = bonobo_control_get_ui_component (control);
 	g_return_if_fail (uic != NULL);
@@ -214,13 +233,19 @@ tasks_control_sensitize_commands (BonoboControl *control, ETasks *tasks, int n_s
 	if (ecal)
 		e_cal_is_read_only (ecal, &read_only, NULL);
 
+	preview = e_cal_component_preview_get_html (E_CAL_COMPONENT_PREVIEW (e_tasks_get_preview (tasks)));
+	if (preview && GTK_WIDGET_VISIBLE (preview) && GTK_WIDGET_HAS_FOCUS (preview))
+		t->target.mask = t->target.mask | E_CAL_TASKS_PREVIEW_ACTIVE;
+	else
+		t->target.mask = t->target.mask & (~E_CAL_TASKS_PREVIEW_ACTIVE);
+
 	sensitize_items (uic, tasks_sensitize_table, t->target.mask);
 	e_menu_update_target ((EMenu *)menu, (EMenuTarget *)t);
 }
 
 /* Callback used when the selection in the table changes */
 static void
-selection_changed_cb (ETasks *tasks, int n_selected, gpointer data)
+selection_changed_cb (ETasks *tasks, gint n_selected, gpointer data)
 {
 	BonoboControl *control;
 
@@ -229,6 +254,16 @@ selection_changed_cb (ETasks *tasks, int n_selected, gpointer data)
 	tasks_control_sensitize_commands (control, tasks, n_selected);
 }
 
+static gboolean
+tasks_control_focus_changed (GtkWidget *widget, GdkEventFocus *event, struct focus_changed_data *fc_data)
+{
+	g_return_val_if_fail (fc_data != NULL, FALSE);
+
+	tasks_control_sensitize_commands (fc_data->control, fc_data->tasks, -1);
+
+	return FALSE;
+}
+
 static BonoboUIVerb verbs [] = {
 	BONOBO_UI_VERB ("TasksOpenTask", tasks_control_open_task_cmd),
 	BONOBO_UI_VERB ("TasksNewTask", tasks_control_new_task_cmd),
@@ -246,19 +281,19 @@ static BonoboUIVerb verbs [] = {
 };
 
 static EPixmap pixmaps [] = {
-	E_PIXMAP ("/commands/TasksCopy", "edit-copy", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/TasksCut", "edit-cut", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/TasksDelete", "edit-delete", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/TasksForward", "mail-forward", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/TasksPaste", "edit-paste", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/TasksPrint", "document-print", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/TasksPrintPreview", "document-print-preview", E_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/TasksCopy", "edit-copy", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/TasksCut", "edit-cut", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/TasksDelete", "edit-delete", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/TasksForward", "mail-forward", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/TasksPaste", "edit-paste", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/TasksPrint", "document-print", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/TasksPrintPreview", "document-print-preview", GTK_ICON_SIZE_MENU),
 
-	E_PIXMAP ("/Toolbar/Cut", "edit-cut", E_ICON_SIZE_LARGE_TOOLBAR),
-	E_PIXMAP ("/Toolbar/Copy", "edit-copy", E_ICON_SIZE_LARGE_TOOLBAR),
-	E_PIXMAP ("/Toolbar/Paste", "edit-paste", E_ICON_SIZE_LARGE_TOOLBAR),
-	E_PIXMAP ("/Toolbar/Print", "document-print", E_ICON_SIZE_LARGE_TOOLBAR),
-	E_PIXMAP ("/Toolbar/Delete", "edit-delete", E_ICON_SIZE_LARGE_TOOLBAR),
+	E_PIXMAP ("/Toolbar/Cut", "edit-cut", GTK_ICON_SIZE_LARGE_TOOLBAR),
+	E_PIXMAP ("/Toolbar/Copy", "edit-copy", GTK_ICON_SIZE_LARGE_TOOLBAR),
+	E_PIXMAP ("/Toolbar/Paste", "edit-paste", GTK_ICON_SIZE_LARGE_TOOLBAR),
+	E_PIXMAP ("/Toolbar/Print", "document-print", GTK_ICON_SIZE_LARGE_TOOLBAR),
+	E_PIXMAP ("/Toolbar/Delete", "edit-delete", GTK_ICON_SIZE_LARGE_TOOLBAR),
 
 	E_PIXMAP_END
 };
@@ -267,11 +302,11 @@ tasks_control_activate (BonoboControl *control, ETasks *tasks)
 {
 	Bonobo_UIContainer remote_uih;
 	BonoboUIComponent *uic;
-	int n_selected;
+	gint n_selected;
 	ECalendarTable *cal_table;
 	ETable *etable;
 	gboolean state;
-	char *xmlfile;
+	gchar *xmlfile;
 
 	uic = bonobo_control_get_ui_component (control);
 	g_return_if_fail (uic != NULL);
@@ -318,7 +353,6 @@ tasks_control_activate (BonoboControl *control, ETasks *tasks)
 	bonobo_ui_component_set_prop(uic, "/commands/ViewPreview", "state", state?"1":"0", NULL);
 }
 
-
 void
 tasks_control_deactivate (BonoboControl *control, ETasks *tasks)
 {
@@ -335,12 +369,12 @@ tasks_control_deactivate (BonoboControl *control, ETasks *tasks)
 	g_signal_handlers_disconnect_matched (tasks, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, control);
 
 	bonobo_ui_component_rm (uic, "/", NULL);
- 	bonobo_ui_component_unset_container (uic, NULL);
+	bonobo_ui_component_unset_container (uic, NULL);
 }
 
 static void tasks_control_open_task_cmd		(BonoboUIComponent	*uic,
 						 gpointer		 data,
-						 const char		*path)
+						 const gchar		*path)
 {
 	ETasks *tasks;
 
@@ -351,7 +385,7 @@ static void tasks_control_open_task_cmd		(BonoboUIComponent	*uic,
 static void
 tasks_control_new_task_cmd		(BonoboUIComponent	*uic,
 					 gpointer		 data,
-					 const char		*path)
+					 const gchar		*path)
 {
 	ETasks *tasks;
 
@@ -362,7 +396,7 @@ tasks_control_new_task_cmd		(BonoboUIComponent	*uic,
 static void
 tasks_control_cut_cmd                   (BonoboUIComponent      *uic,
 					 gpointer                data,
-					 const char             *path)
+					 const gchar             *path)
 {
 	ETasks *tasks;
 	ECalendarTable *cal_table;
@@ -375,20 +409,28 @@ tasks_control_cut_cmd                   (BonoboUIComponent      *uic,
 static void
 tasks_control_copy_cmd                  (BonoboUIComponent      *uic,
 					 gpointer                data,
-					 const char             *path)
+					 const gchar             *path)
 {
 	ETasks *tasks;
 	ECalendarTable *cal_table;
+	GtkWidget *preview;
 
 	tasks = E_TASKS (data);
-	cal_table = e_tasks_get_calendar_table (tasks);
-	e_calendar_table_copy_clipboard (cal_table);
+
+	preview = e_cal_component_preview_get_html (E_CAL_COMPONENT_PREVIEW (e_tasks_get_preview (tasks)));
+	if (preview && GTK_WIDGET_VISIBLE (preview) && GTK_WIDGET_HAS_FOCUS (preview)) {
+		/* copy selected text in a preview when that's shown and focused */
+		gtk_html_copy (GTK_HTML (preview));
+	} else {
+		cal_table = e_tasks_get_calendar_table (tasks);
+		e_calendar_table_copy_clipboard (cal_table);
+	}
 }
 
 static void
 tasks_control_paste_cmd                 (BonoboUIComponent      *uic,
 					 gpointer                data,
-					 const char             *path)
+					 const gchar             *path)
 {
 	ETasks *tasks;
 	ECalendarTable *cal_table;
@@ -401,7 +443,7 @@ tasks_control_paste_cmd                 (BonoboUIComponent      *uic,
 static void
 tasks_control_delete_cmd		(BonoboUIComponent	*uic,
 					 gpointer		 data,
-					 const char		*path)
+					 const gchar		*path)
 {
 	ETasks *tasks;
 
@@ -412,7 +454,7 @@ tasks_control_delete_cmd		(BonoboUIComponent	*uic,
 static void
 tasks_control_complete_cmd		(BonoboUIComponent	*uic,
 					 gpointer		 data,
-					 const char		*path)
+					 const gchar		*path)
 {
 	ETasks *tasks;
 
@@ -427,7 +469,7 @@ static gboolean
 confirm_purge (ETasks *tasks)
 {
 	GtkWidget *dialog, *checkbox, *parent;
-	int button;
+	gint button;
 
 	if (!calendar_config_get_confirm_purge ())
 		return TRUE;
@@ -438,7 +480,7 @@ confirm_purge (ETasks *tasks)
 		GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_MESSAGE_WARNING,
 		GTK_BUTTONS_YES_NO,
-		"%s", 
+		"%s",
 		_("This operation will permanently erase all tasks marked as completed. If you continue, you will not be able to recover these tasks.\n\nReally erase these tasks?"));
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_NO);
 
@@ -457,7 +499,7 @@ confirm_purge (ETasks *tasks)
 static void
 tasks_control_purge_cmd	(BonoboUIComponent	*uic,
 			 gpointer		 data,
-			 const char		*path)
+			 const gchar		*path)
 {
 	ETasks *tasks;
 
@@ -470,7 +512,7 @@ tasks_control_purge_cmd	(BonoboUIComponent	*uic,
 static void
 tasks_control_print_cmd (BonoboUIComponent *uic,
 			 gpointer data,
-			 const char *path)
+			 const gchar *path)
 {
 	ETasks *tasks = E_TASKS (data);
 	ETable *table;
@@ -486,7 +528,7 @@ tasks_control_print_cmd (BonoboUIComponent *uic,
 static void
 tasks_control_print_preview_cmd (BonoboUIComponent *uic,
 				 gpointer data,
-				 const char *path)
+				 const gchar *path)
 {
 	ETasks *tasks = E_TASKS (data);
 	ETable *table;
@@ -502,7 +544,7 @@ tasks_control_print_preview_cmd (BonoboUIComponent *uic,
 static void
 tasks_control_assign_cmd (BonoboUIComponent *uic,
                          gpointer data,
-                         const char *path)
+                         const gchar *path)
 {
               ETasks *tasks;
               ECalendarTable *cal_table;
@@ -511,16 +553,16 @@ tasks_control_assign_cmd (BonoboUIComponent *uic,
               tasks = E_TASKS (data);
               cal_table = e_tasks_get_calendar_table (tasks);
               comp_data = e_calendar_table_get_selected_comp (cal_table);
- 	       if (comp_data)
+	       if (comp_data)
               e_calendar_table_open_task (cal_table, comp_data->client, comp_data->icalcomp, TRUE);
 }
 
 static void
 tasks_control_forward_cmd (BonoboUIComponent *uic,
                          gpointer data,
-                          const char *path)
+                          const gchar *path)
 {
-	        ETasks *tasks;
+		ETasks *tasks;
                ECalendarTable *cal_table;
                ECalModelComponent *comp_data;
 
@@ -537,7 +579,7 @@ tasks_control_forward_cmd (BonoboUIComponent *uic,
 }
 
 static void
-tasks_control_view_preview (BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_EventType type, const char *state, void *data)
+tasks_control_view_preview (BonoboUIComponent *uic, const gchar *path, Bonobo_UIComponent_EventType type, const gchar *state, gpointer data)
 {
         ETasks *tasks;
 
