@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -178,7 +178,7 @@ sig_load_preview (EMComposerPrefs *prefs,
 		gtk_html_load_from_string (html, str, strlen (str));
 	} else {
 		GtkHTMLStream *stream;
-		int len;
+		gint len;
 
 		len = strlen (str);
 		stream = gtk_html_begin_content (html, "text/html; charset=utf-8");
@@ -376,12 +376,12 @@ sig_add_cb (GtkWidget *widget, EMComposerPrefs *prefs)
 }
 
 static void
-sig_add_script_response (GtkWidget *widget, int button, EMComposerPrefs *prefs)
+sig_add_script_response (GtkWidget *widget, gint button, EMComposerPrefs *prefs)
 {
 	gchar *script, **argv = NULL;
 	GtkWidget *entry;
 	const gchar *name;
-	int argc;
+	gint argc;
 
 	if (button == GTK_RESPONSE_ACCEPT) {
 		entry = glade_xml_get_widget (prefs->sig_script_gui, "filechooserbutton_add_script");
@@ -762,16 +762,16 @@ emcp_widget_glade (EConfig *ec,
 
 /* plugin meta-data */
 static EMConfigItem emcp_items[] = {
-	{ E_CONFIG_BOOK, "", "composer_toplevel", emcp_widget_glade },
-	{ E_CONFIG_PAGE, "00.general", "vboxGeneral", emcp_widget_glade },
-	{ E_CONFIG_SECTION, "00.general/00.behavior", "vboxBehavior", emcp_widget_glade },
-	{ E_CONFIG_SECTION, "00.general/10.alerts", "vboxAlerts", emcp_widget_glade },
-	{ E_CONFIG_PAGE, "10.signatures", "vboxSignatures", emcp_widget_glade },
+	{ E_CONFIG_BOOK, (gchar *) "", (gchar *) "composer_toplevel", emcp_widget_glade },
+	{ E_CONFIG_PAGE, (gchar *) "00.general", (gchar *) "vboxGeneral", emcp_widget_glade },
+	{ E_CONFIG_SECTION, (gchar *) "00.general/00.behavior", (gchar *) "vboxBehavior", emcp_widget_glade },
+	{ E_CONFIG_SECTION, (gchar *) "00.general/10.alerts", (gchar *) "vboxAlerts", emcp_widget_glade },
+	{ E_CONFIG_PAGE, (gchar *) "10.signatures", (gchar *) "vboxSignatures", emcp_widget_glade },
 	/* signature/signatures and signature/preview parts not usable */
 
-	{ E_CONFIG_PAGE, "20.spellcheck", "vboxSpellChecking", emcp_widget_glade },
-	{ E_CONFIG_SECTION, "20.spellcheck/00.languages", "vbox178", emcp_widget_glade },
-	{ E_CONFIG_SECTION, "20.spellcheck/00.options", "vboxOptions", emcp_widget_glade },
+	{ E_CONFIG_PAGE, (gchar *) "20.spellcheck", (gchar *) "vboxSpellChecking", emcp_widget_glade },
+	{ E_CONFIG_SECTION, (gchar *) "20.spellcheck/00.languages", (gchar *) "vbox178", emcp_widget_glade },
+	{ E_CONFIG_SECTION, (gchar *) "20.spellcheck/00.options", (gchar *) "vboxOptions", emcp_widget_glade },
 };
 
 static void
@@ -821,12 +821,12 @@ em_composer_prefs_construct (EMComposerPrefs *prefs)
 	GConfBridge *bridge;
 	GConfClient *client;
 	const gchar *key;
-	int style;
+	gint style;
 	gchar *buf;
 	EMConfig *ec;
 	EMConfigTargetPrefs *target;
 	GSList *l;
-	int i;
+	gint i;
 	gchar *gladefile;
 	gboolean sensitive;
 
@@ -945,7 +945,7 @@ em_composer_prefs_construct (EMComposerPrefs *prefs)
 
 	gtk_tree_view_insert_column_with_attributes (
 		view, -1, _("Language(s)"),
-     		gtk_cell_renderer_text_new (),
+		gtk_cell_renderer_text_new (),
 		"text", 1, NULL);
 	selection = gtk_tree_view_get_selection (view);
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_NONE);
@@ -956,15 +956,15 @@ em_composer_prefs_construct (EMComposerPrefs *prefs)
 	spell_setup (prefs);
 
 	/* Forwards and Replies */
-	prefs->forward_style = GTK_COMBO_BOX (glade_xml_get_widget (gui, "comboboxForwardStyle")); 
+	prefs->forward_style = GTK_COMBO_BOX (glade_xml_get_widget (gui, "comboboxForwardStyle"));
 	style = gconf_client_get_int (client, "/apps/evolution/mail/format/forward_style", NULL);
 	gtk_combo_box_set_active (prefs->forward_style, style);
-	g_signal_connect (prefs->forward_style, "changed", G_CALLBACK (style_changed), "/apps/evolution/mail/format/forward_style");
+	g_signal_connect (prefs->forward_style, "changed", G_CALLBACK (style_changed), (gpointer) "/apps/evolution/mail/format/forward_style");
 
 	prefs->reply_style = GTK_COMBO_BOX (glade_xml_get_widget (gui, "comboboxReplyStyle"));
 	style = gconf_client_get_int (client, "/apps/evolution/mail/format/reply_style", NULL);
 	gtk_combo_box_set_active (prefs->reply_style, reply_style_new_order (style, TRUE));
-	g_signal_connect (prefs->reply_style, "changed", G_CALLBACK (style_changed), "/apps/evolution/mail/format/reply_style");
+	g_signal_connect (prefs->reply_style, "changed", G_CALLBACK (style_changed), (gpointer) "/apps/evolution/mail/format/reply_style");
 
 	/* Signatures */
 	dialog = (GtkDialog *) gtk_dialog_new ();
