@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -34,8 +34,8 @@ e_calendar_file_dummy (EPlugin *epl, EConfigHookItemFactoryData *data)
 {
 	ECalConfigTargetSource *t = (ECalConfigTargetSource *) data->target;
 	ESource *source = t->source;
-	char *uri_text;
-	const char *relative_uri;
+	gchar *uri_text;
+	const gchar *relative_uri;
 
         uri_text = e_source_get_uri (source);
 	if (strncmp (uri_text, "file", 4)) {
