@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -56,7 +56,6 @@ commit_default_book (EPlugin *epl, EConfigTarget *target)
 	if (e_source_get_property (source, "default"))
 		e_book_set_default_source (source, NULL);
 
-
 }
 
 static void
@@ -69,7 +68,6 @@ default_source_changed (GtkWidget *check_box,  ESource *source)
 		e_source_set_property (source, "default", NULL);
 }
 
-
 GtkWidget *
 org_gnome_default_book (EPlugin *epl, EConfigHookItemFactoryData *data)
 {
@@ -94,10 +92,10 @@ org_gnome_default_book (EPlugin *epl, EConfigHookItemFactoryData *data)
 	return widget;
 }
 
-static const char *
+static const gchar *
 get_calendar_option_caption (ECalSourceType source_type)
 {
-	const char *res = "???";
+	const gchar *res = "???";
 
 	switch (source_type) {
 		case E_CAL_SOURCE_TYPE_EVENT:   res = _("Mark as _default calendar"); break;
@@ -117,7 +115,7 @@ org_gnome_default_cal (EPlugin *epl, EConfigHookItemFactoryData *data)
 	GtkWidget *widget;
 	ESource *source;
 	ECalConfigTargetSource *cal_target;
-	int i;
+	gint i;
 
 	if (data->old)
 		return data->old;
