@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -50,7 +50,7 @@ action_face_cb (GtkAction *action,
 	if (error) {
 
 		GtkWidget *filesel;
-		const char *image_filename;
+		const gchar *image_filename;
 		gsize length;
 
 		GtkFileFilter *filter;
@@ -89,7 +89,7 @@ action_face_cb (GtkAction *action,
 
 					pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
 					if (pixbuf) {
-						int width, height;
+						gint width, height;
 
 						g_object_ref (pixbuf);
 
