@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -36,7 +36,7 @@
 /*stores some info about all currently existing groupwise accounts
   list of GwAccountInfo structures */
 
-static 	GList *groupwise_accounts = NULL;
+static	GList *groupwise_accounts = NULL;
 
 struct _CamelGwListenerPrivate {
 	GConfClient *gconf_client;
@@ -45,9 +45,9 @@ struct _CamelGwListenerPrivate {
 };
 
 struct _GwAccountInfo {
-	char *uid;
-	char *name;
-	char *source_url;
+	gchar *uid;
+	gchar *name;
+	gchar *source_url;
 	gboolean auto_check;
 	guint auto_check_time;
 };
@@ -64,7 +64,6 @@ static GObjectClass *parent_class = NULL;
 static void dispose (GObject *object);
 static void finalize (GObject *object);
 
-
 static void
 camel_gw_listener_class_init (CamelGwListenerClass *class)
 {
@@ -106,7 +105,7 @@ finalize (GObject *object)
 		g_free (config_listener->priv);
 	}
 
-	for ( list = g_list_first (groupwise_accounts); list ; list = g_list_next (list) ) {
+	for ( list = g_list_first (groupwise_accounts); list; list = g_list_next (list) ) {
 
 		info = (GwAccountInfo *) (list->data);
 
@@ -139,11 +138,11 @@ is_groupwise_account (EAccount *account)
 /* looks up for an existing groupwise account info in the groupwise_accounts list based on uid */
 
 static GwAccountInfo*
-lookup_account_info (const char *key)
+lookup_account_info (const gchar *key)
 {
 	GList *list;
-        GwAccountInfo *info ;
-	int found = 0;
+        GwAccountInfo *info;
+	gint found = 0;
 
         if (!key)
                 return NULL;
@@ -169,20 +168,20 @@ lookup_account_info (const char *key)
 #define SELECTED_NOTES   "/apps/evolution/calendar/memos/selected_memos"
 
 static void
-add_esource (const char *conf_key, GwAccountInfo *info,  const char *source_name, CamelURL *url, const char* parent_id_name, gboolean can_create)
+add_esource (const gchar *conf_key, GwAccountInfo *info,  const gchar *source_name, CamelURL *url, const gchar * parent_id_name, gboolean can_create)
 {
 	ESourceList *source_list;
 	ESourceGroup *group;
 	ESource *source;
         GConfClient* client;
-	GSList *ids, *temp ;
-	char *source_selection_key;
-	char *relative_uri;
-	const char *soap_port;
-	const char * use_ssl;
-	const char *poa_address;
-	const char *offline_sync;
-	const char *group_name;
+	GSList *ids, *temp;
+	const gchar *source_selection_key;
+	gchar *relative_uri;
+	const gchar *soap_port;
+	const gchar * use_ssl;
+	const gchar *poa_address;
+	const gchar *offline_sync;
+	const gchar *group_name;
 
 	poa_address = url->host;
 	if (!poa_address || strlen (poa_address) ==0)
@@ -192,12 +191,11 @@ add_esource (const char *conf_key, GwAccountInfo *info,  const char *source_name
 
 	soap_port = camel_url_get_param (url, "soap_port");
 
- 	if (!soap_port || strlen (soap_port) == 0)
+	if (!soap_port || strlen (soap_port) == 0)
 		soap_port = "7191";
 
 	use_ssl = camel_url_get_param (url, "use_ssl");
 
-
 	offline_sync = camel_url_get_param (url, "offline_sync");
 
 	client = gconf_client_get_default();
@@ -210,7 +208,6 @@ add_esource (const char *conf_key, GwAccountInfo *info,  const char *source_name
 	if (!can_create)
 		e_source_group_set_property (group, "create_source", "no");
 
-
 	relative_uri = g_strdup_printf ("%s@%s/", url->user, poa_address);
 	source = e_source_new (source_name, relative_uri);
 	e_source_set_property (source, "auth", "1");
@@ -220,11 +217,11 @@ add_esource (const char *conf_key, GwAccountInfo *info,  const char *source_name
 	e_source_set_property (source, "use_ssl", use_ssl);
 
 	if (info->auto_check) {
-		char *str = g_strdup_printf ("%d", info->auto_check_time);
+		gchar *str = g_strdup_printf ("%d", info->auto_check_time);
 
 		e_source_set_property (source, "refresh", str);
 		g_free (str);
-	} else 
+	} else
 		e_source_set_property (source, "refresh", NULL);
 
 	e_source_set_property (source, "offline_sync", offline_sync ? "1" : "0" );
@@ -266,7 +263,7 @@ add_esource (const char *conf_key, GwAccountInfo *info,  const char *source_name
 }
 
 static void
-remove_esource (const char *conf_key, const char *group_name, char* source_name, const char* relative_uri)
+remove_esource (const gchar *conf_key, const gchar *group_name, gchar * source_name, const gchar * relative_uri)
 {
 	ESourceList *list;
         GSList *groups;
@@ -274,7 +271,7 @@ remove_esource (const char *conf_key, const char *group_name, char* source_name,
 	GConfClient* client;
 	GSList *ids;
 	GSList *node_tobe_deleted;
-	char *source_selection_key;
+	const gchar *source_selection_key;
 
         client = gconf_client_get_default();
         list = e_source_list_new_for_gconf (client, conf_key);
@@ -282,14 +279,14 @@ remove_esource (const char *conf_key, const char *group_name, char* source_name,
 
 	found_group = FALSE;
 
-	for ( ; groups != NULL && !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL && !found_group; groups = g_slist_next (groups)) {
 		ESourceGroup *group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), group_name) == 0 &&
 		   strcmp (e_source_group_peek_base_uri (group), GROUPWISE_URI_PREFIX ) == 0) {
 			GSList *sources = e_source_group_peek_sources (group);
 
-			for( ; sources != NULL; sources = g_slist_next (sources)) {
+			for(; sources != NULL; sources = g_slist_next (sources)) {
 				ESource *source = E_SOURCE (sources->data);
 				const gchar *source_relative_uri;
 
@@ -327,7 +324,6 @@ remove_esource (const char *conf_key, const char *group_name, char* source_name,
 
 		}
 
-
 	}
 
 	g_object_unref (list);
@@ -338,18 +334,18 @@ remove_esource (const char *conf_key, const char *group_name, char* source_name,
 /* looks up for e-source with having same info as old_account_info and changes its values passed in new values */
 
 static void
-modify_esource (const char* conf_key, GwAccountInfo *old_account_info, EAccount *a, CamelURL *new_url)
+modify_esource (const gchar * conf_key, GwAccountInfo *old_account_info, EAccount *a, CamelURL *new_url)
 {
 	ESourceList *list;
         GSList *groups;
-	char *old_relative_uri;
+	gchar *old_relative_uri;
 	CamelURL *url;
 	gboolean found_group;
-      	GConfClient* client;
-	const char *poa_address;
-	const char *new_poa_address;
-	const char* new_group_name = a->name;
-	
+	GConfClient* client;
+	const gchar *poa_address;
+	const gchar *new_poa_address;
+	const gchar * new_group_name = a->name;
+
 	url = camel_url_new (old_account_info->source_url, NULL);
 	poa_address = url->host;
 	if (!poa_address || strlen (poa_address) ==0)
@@ -363,14 +359,14 @@ modify_esource (const char* conf_key, GwAccountInfo *old_account_info, EAccount
 
 	found_group = FALSE;
 
-	for ( ; groups != NULL &&  !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL &&  !found_group; groups = g_slist_next (groups)) {
 		ESourceGroup *group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), old_account_info->name) == 0 &&
 		    strcmp (e_source_group_peek_base_uri (group), GROUPWISE_URI_PREFIX) == 0) {
 			GSList *sources = e_source_group_peek_sources (group);
 
-			for ( ; sources != NULL; sources = g_slist_next (sources)) {
+			for (; sources != NULL; sources = g_slist_next (sources)) {
 				ESource *source = E_SOURCE (sources->data);
 				const gchar *source_relative_uri;
 
@@ -387,13 +383,13 @@ modify_esource (const char* conf_key, GwAccountInfo *old_account_info, EAccount
 					e_source_set_property (source, "port", camel_url_get_param (new_url,"soap_port"));
 					e_source_set_property (source, "use_ssl",  camel_url_get_param (url, "use_ssl"));
 					e_source_set_property (source, "offline_sync",  camel_url_get_param (url, "offline_sync") ? "1" : "0");
-				
+
 					if (a->source->auto_check) {
-						char *str = g_strdup_printf ("%d", a->source->auto_check_time);
-					
+						gchar *str = g_strdup_printf ("%d", a->source->auto_check_time);
+
 						e_source_set_property (source, "refresh", str);
 						g_free (str);
-					} else 
+					} else
 						e_source_set_property (source, "refresh", NULL);
 
 					e_source_list_sync (list, NULL);
@@ -410,7 +406,6 @@ modify_esource (const char* conf_key, GwAccountInfo *old_account_info, EAccount
 	camel_url_free (url);
 	g_free (old_relative_uri);
 
-
 }
 /* add sources for calendar and tasks if the account added is groupwise account
    adds the new account info to  groupwise_accounts list */
@@ -424,9 +419,8 @@ add_calendar_tasks_sources (GwAccountInfo *info)
 	add_esource ("/apps/evolution/calendar/sources", info, _("Calendar"), url, NULL, FALSE);
 	add_esource ("/apps/evolution/tasks/sources", info, _("Tasks"), url, NULL, FALSE);
 	add_esource ("/apps/evolution/memos/sources", info, _("Notes"), url, NULL, TRUE);
- 
-	camel_url_free (url);
 
+	camel_url_free (url);
 
 }
 
@@ -437,9 +431,9 @@ static void
 remove_calendar_tasks_sources (GwAccountInfo *info)
 {
 	CamelURL *url;
-	char *relative_uri;
-        const char *soap_port;
-	const char *poa_address;
+	gchar *relative_uri;
+        const gchar *soap_port;
+	const gchar *poa_address;
 
 	url = camel_url_new (info->source_url, NULL);
 
@@ -462,22 +456,22 @@ remove_calendar_tasks_sources (GwAccountInfo *info)
 }
 
 static GList*
-get_addressbook_names_from_server (char *source_url)
+get_addressbook_names_from_server (gchar *source_url)
 {
-  	char *key;
+	gchar *key;
         EGwConnection *cnc;
-	char *password;
+	gchar *password;
 	GList *book_list = NULL;
-	int status, count = 0;
-	const char *soap_port;
+	gint status, count = 0;
+	const gchar *soap_port;
 	CamelURL *url;
 	gboolean remember;
-	char *failed_auth = NULL;
-	char *prompt;
-	char *password_prompt;
-	char *uri;
-	const char *use_ssl;
-	const char *poa_address;
+	gchar *failed_auth = NULL;
+	gchar *prompt;
+	gchar *password_prompt;
+	gchar *uri;
+	const gchar *use_ssl;
+	const gchar *poa_address;
 	guint32 flags = E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET;
 
 	url = camel_url_new (source_url, NULL);
@@ -552,10 +546,10 @@ get_addressbook_names_from_server (char *source_url)
 }
 
 static void
-add_proxy_sources (GwAccountInfo *info, const char *parent_name)
+add_proxy_sources (GwAccountInfo *info, const gchar *parent_name)
 {
 	CamelURL *url;
-	char *color;
+	gchar *color;
 
 	url = camel_url_new (info->source_url, NULL);
 
@@ -580,12 +574,12 @@ add_addressbook_sources (EAccount *account)
 	ESourceList *list;
         ESourceGroup *group;
         ESource *source;
-       	char *base_uri;
-	const char *soap_port;
+	gchar *base_uri;
+	const gchar *soap_port;
 	GList *books_list, *temp_list;
 	GConfClient* client;
-	const char* use_ssl;
-	const char *poa_address;
+	const gchar * use_ssl;
+	const gchar *poa_address;
 	gboolean is_frequent_contacts = FALSE, is_writable = FALSE;
 
         url = camel_url_new (account->source->url, NULL);
@@ -610,7 +604,7 @@ add_addressbook_sources (EAccount *account)
 	if (!temp_list)
 		return FALSE;
 	for (; temp_list != NULL; temp_list = g_list_next (temp_list)) {
-		const char *book_name =  e_gw_container_get_name (E_GW_CONTAINER(temp_list->data));
+		const gchar *book_name =  e_gw_container_get_name (E_GW_CONTAINER(temp_list->data));
 		/* is_writable is set to TRUE if the book has isPersonal property,
 		 * by e_gw_connection_get_address_book_list()
 		 */
@@ -671,17 +665,16 @@ modify_addressbook_sources ( EAccount *account, GwAccountInfo *existing_account_
 	ESourceList *list;
         ESourceGroup *group;
 	GSList *groups;
-       	gboolean found_group;
+	gboolean found_group;
 	gboolean delete_group;
-	char *old_base_uri;
-	char *new_base_uri;
-	const char *soap_port;
-	const char *use_ssl;
+	gchar *old_base_uri;
+	gchar *new_base_uri;
+	const gchar *soap_port;
+	const gchar *use_ssl;
 	GSList *sources;
 	ESource *source;
 	GConfClient *client;
-	const char *poa_address;
-
+	const gchar *poa_address;
 
 	url = camel_url_new (existing_account_info->source_url, NULL);
 	if (url == NULL) {
@@ -697,7 +690,7 @@ modify_addressbook_sources ( EAccount *account, GwAccountInfo *existing_account_
 
 	url = camel_url_new (account->source->url, NULL);
 	if (url == NULL)
-		return ;
+		return;
 	poa_address = url->host;
 	if (!poa_address || strlen (poa_address) ==0)
 		return;
@@ -715,7 +708,7 @@ modify_addressbook_sources ( EAccount *account, GwAccountInfo *existing_account_
 		delete_group = TRUE;
 	group = NULL;
 	found_group = FALSE;
-	for ( ; groups != NULL &&  !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL &&  !found_group; groups = g_slist_next (groups)) {
 
 		group = E_SOURCE_GROUP (groups->data);
 		if ( strcmp ( e_source_group_peek_base_uri(group), old_base_uri) == 0 && strcmp (e_source_group_peek_name (group), existing_account_info->name) == 0) {
@@ -747,7 +740,6 @@ modify_addressbook_sources ( EAccount *account, GwAccountInfo *existing_account_
 	camel_url_free (url);
 	g_object_unref (client);
 
-
 }
 
 static void
@@ -756,12 +748,12 @@ remove_addressbook_sources (GwAccountInfo *existing_account_info)
 	ESourceList *list;
         ESourceGroup *group;
 	GSList *groups;
-       	gboolean found_group;
+	gboolean found_group;
 	CamelURL *url;
-	char *base_uri;
-	const char *soap_port;
+	gchar *base_uri;
+	const gchar *soap_port;
 	GConfClient *client;
-	const char *poa_address;
+	const gchar *poa_address;
 
 	url = camel_url_new (existing_account_info->source_url, NULL);
 	if (url == NULL) {
@@ -782,7 +774,7 @@ remove_addressbook_sources (GwAccountInfo *existing_account_info)
 
 	found_group = FALSE;
 
-	for ( ; groups != NULL &&  !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL &&  !found_group; groups = g_slist_next (groups)) {
 
 		group = E_SOURCE_GROUP (groups->data);
 		if ( strcmp ( e_source_group_peek_base_uri (group), base_uri) == 0 && strcmp (e_source_group_peek_name (group), existing_account_info->name) == 0) {
@@ -798,7 +790,6 @@ remove_addressbook_sources (GwAccountInfo *existing_account_info)
 	g_free (base_uri);
 	camel_url_free (url);
 
-
 }
 
 static void
@@ -839,7 +830,7 @@ account_added (EAccountList *account_listener, EAccount *account)
 static void
 account_removed (EAccountList *account_listener, EAccount *account)
 {
-       	GwAccountInfo *info;
+	GwAccountInfo *info;
 
 	if (!is_groupwise_account (account))
 		return;
@@ -857,16 +848,15 @@ account_removed (EAccountList *account_listener, EAccount *account)
         g_free (info);
 }
 
-
 static void
 account_changed (EAccountList *account_listener, EAccount *account)
 {
 	gboolean is_gw_account;
 	CamelURL *old_url, *new_url;
-	const char *old_soap_port, *new_soap_port;
+	const gchar *old_soap_port, *new_soap_port;
 	GwAccountInfo *existing_account_info;
-	const char *old_use_ssl, *new_use_ssl;
-	const char *old_poa_address, *new_poa_address;
+	const gchar *old_use_ssl, *new_use_ssl;
+	const gchar *old_poa_address, *new_poa_address;
 
 	is_gw_account = is_groupwise_account (account);
 
@@ -919,7 +909,7 @@ account_changed (EAccountList *account_listener, EAccount *account)
 		if ((old_poa_address && strcmp (old_poa_address, new_poa_address))
 		   ||  (old_soap_port && strcmp (old_soap_port, new_soap_port))
 		   ||  strcmp (old_url->user, new_url->user)
-	           || (!old_use_ssl)
+		   || (!old_use_ssl)
 		   || strcmp (old_use_ssl, new_use_ssl)) {
 
 			account_removed (account_listener, account);
@@ -953,7 +943,7 @@ prune_proxies (void) {
 	ESource *source;
 	GError *err = NULL;
 	const gchar *parent_id_name = NULL;
-	int i;
+	gint i;
 	ECalSourceType types [] = { E_CAL_SOURCE_TYPE_EVENT,
 				    E_CAL_SOURCE_TYPE_TODO,
 				    E_CAL_SOURCE_TYPE_JOURNAL
@@ -994,19 +984,19 @@ camel_gw_listener_construct (CamelGwListener *config_listener)
 {
 	EIterator *iter;
 	EAccount *account;
-	GwAccountInfo *info ;
+	GwAccountInfo *info;
 
 	prune_proxies ();
 
-       	config_listener->priv->account_list = e_account_list_new (config_listener->priv->gconf_client);
+	config_listener->priv->account_list = e_account_list_new (config_listener->priv->gconf_client);
 
-	for ( iter = e_list_get_iterator (E_LIST ( config_listener->priv->account_list) ) ; e_iterator_is_valid (iter); e_iterator_next (iter) ) {
+	for ( iter = e_list_get_iterator (E_LIST ( config_listener->priv->account_list) ); e_iterator_is_valid (iter); e_iterator_next (iter) ) {
 
 		account = E_ACCOUNT (e_iterator_get (iter));
 
 		if ( is_groupwise_account (account) && account->enabled) {
 
-		        info = g_new0 (GwAccountInfo, 1);
+			info = g_new0 (GwAccountInfo, 1);
 			info->uid = g_strdup (account->uid);
 			info->name = g_strdup (account->name);
 			info->source_url = g_strdup (account->source->url);
