@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -38,9 +38,9 @@ org_gnome_evolution_profiler_event(EPlugin *ep, EProfileEventTarget *t)
 	static FILE *fp;
 
 	if (!fp) {
-		char *name;
+		gchar *name;
 
-		name = g_strdup_printf("eprofile.%ld", (long int)getpid());
+		name = g_strdup_printf("eprofile.%ld", (glong)getpid());
 		fp = fopen(name, "w");
 		if (fp)
 			fprintf(stderr, "Generating profiling data in `%s'\n", name);
