@@ -129,7 +129,11 @@ unmount_done_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
 	GError *error = NULL;
 
+#if GLIB_CHECK_VERSION(2,21,3)
+	g_mount_unmount_with_operation_finish (G_MOUNT (source_object), res, &error);
+#else
 	g_mount_unmount_finish (G_MOUNT (source_object), res, &error);
+#endif
 
 	if (error) {
 		g_warning ("Unmount failed: %s", error->message);
@@ -177,7 +181,11 @@ mount_ready_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
 
 	mount = g_file_find_enclosing_mount (G_FILE (source_object), NULL, NULL);
 	if (mount)
+#if GLIB_CHECK_VERSION(2,21,3)
+		g_mount_unmount_with_operation (mount, G_MOUNT_UNMOUNT_NONE, NULL, NULL, unmount_done_cb, NULL);
+#else
 		g_mount_unmount (mount, G_MOUNT_UNMOUNT_NONE, NULL, unmount_done_cb, NULL);
+#endif
 
 	g_object_unref (source_object);
 }
