@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -121,8 +121,8 @@ typedef struct _ImportData {
 #endif
 
 static struct {
-	char *name;
-	char *text;
+	const gchar *name;
+	const gchar *text;
 } info[] = {
 	{ "type_html",
 	  N_("Choose the type of importer to run:")
@@ -147,10 +147,10 @@ static struct {
 #define num_info (sizeof (info) / sizeof (info[0]))
 
 static GtkWidget *
-create_help (const char *name)
+create_help (const gchar *name)
 {
 	GtkWidget *label;
-	int i;
+	gint i;
 
 	for (i = 0; i < num_info; i++) {
 		if (!strcmp (name, info[i].name))
@@ -160,7 +160,6 @@ create_help (const char *name)
 	if (i >= num_info)
 		g_warning ("i > num_info\n");
 
-
 	label = gtk_label_new(i < num_info ? _(info[i].text): NULL);
 	gtk_widget_show (label);
 	gtk_label_set_line_wrap((GtkLabel *)label, TRUE);
@@ -175,8 +174,8 @@ filename_changed (GtkWidget *widget,
 		  ImportData *data)
 {
 	ImportDialogFilePage *page;
-	const char *filename;
-	int fileok;
+	const gchar *filename;
+	gint fileok;
 
 	page = data->filepage;
 
@@ -189,7 +188,7 @@ filename_changed (GtkWidget *widget,
 		gboolean valid;
 		GSList *l;
 		EImportImporter *first = NULL;
-		int i=0, firstitem=0;
+		gint i=0, firstitem=0;
 
 		g_free(page->target->uri_src);
 		page->target->uri_src = g_filename_to_uri(filename, NULL, NULL);
@@ -252,13 +251,13 @@ filetype_changed_cb (GtkWidget *combobox, ImportData *data)
 }
 
 #if 0
-static int
-compare_info_name (const void *data1, const void  *data2)
+static gint
+compare_info_name (gconstpointer data1, const void  *data2)
 {
 	const Bonobo_ServerInfo *info1 = (Bonobo_ServerInfo *)data1;
 	const Bonobo_ServerInfo *info2 = (Bonobo_ServerInfo *)data2;
-	const char *name1 = get_name_from_component_info (info1);
-	const char *name2 = get_name_from_component_info (info2);
+	const gchar *name1 = get_name_from_component_info (info1);
+	const gchar *name2 = get_name_from_component_info (info2);
 
 	/* If we can't find a name for a plug-in, its iid will be used
 	 * for display. Put such plug-ins at the end of the list since
@@ -281,7 +280,7 @@ importer_file_page_new (ImportData *data)
 	GtkWidget *table, *label;
 	GtkCellRenderer *cell;
 	GtkListStore *store;
-	int row = 0;
+	gint row = 0;
 
 	page = g_new0 (ImportDialogFilePage, 1);
 
@@ -390,7 +389,7 @@ prepare_intelligent_page (GnomeDruidPage *dpage,
 {
 	GSList *l;
 	GtkWidget *table;
-	int row;
+	gint row;
 	ImportDialogImporterPage *page = data->importerpage;
 
 	if (page->target != NULL)
@@ -412,7 +411,7 @@ prepare_intelligent_page (GnomeDruidPage *dpage,
 	row = 0;
 	for (;l;l=l->next) {
 		EImportImporter *eii = l->data;
-		char *str;
+		gchar *str;
 		GtkWidget *w, *label;
 
 		w = e_import_get_widget(data->import, (EImportTarget *)page->target, eii);
@@ -440,7 +439,7 @@ static void
 import_druid_cancel (GnomeDruid *druid,
 		     ImportData *data)
 {
-  	gtk_widget_destroy (GTK_WIDGET (data->dialog));
+	gtk_widget_destroy (GTK_WIDGET (data->dialog));
 }
 
 static gboolean
@@ -456,7 +455,7 @@ import_druid_esc (GnomeDruid *druid,
 }
 
 static void
-import_druid_weak_notify (void *blah,
+import_druid_weak_notify (gpointer blah,
 			  GObject *where_the_object_was)
 {
 	ImportData *data = (ImportData *) blah;
@@ -475,7 +474,7 @@ import_druid_weak_notify (void *blah,
 }
 
 static void
-import_status(EImport *import, const char *what, int pc, void *d)
+import_status(EImport *import, const gchar *what, gint pc, gpointer d)
 {
 	ImportData *data = d;
 
@@ -491,7 +490,7 @@ import_dialog_response(GtkDialog *d, guint button, ImportData *data)
 }
 
 static void
-import_done(EImport *ei, void *d)
+import_done(EImport *ei, gpointer d)
 {
 	ImportData *data = d;
 
@@ -500,7 +499,7 @@ import_done(EImport *ei, void *d)
 }
 
 static void
-import_intelligent_done(EImport *ei, void *d)
+import_intelligent_done(EImport *ei, gpointer d)
 {
 	ImportData *data = d;
 
@@ -519,7 +518,7 @@ import_druid_finish (GnomeDruidPage *page,
 		     ImportData *data)
 {
 	EImportCompleteFunc done = NULL;
-	char *msg = NULL;
+	gchar *msg = NULL;
 
 	if (gtk_toggle_button_get_active((GtkToggleButton *)data->typepage->intelligent)) {
 		data->importerpage->current = data->importerpage->importers;
@@ -677,7 +676,7 @@ back_intelligent_page (GnomeDruidPage *page,
 }
 
 static void
-dialog_weak_notify (void *data,
+dialog_weak_notify (gpointer data,
 		    GObject *where_the_dialog_was)
 {
 	gboolean *dialog_open = (gboolean *) data;
@@ -692,7 +691,7 @@ e_shell_importer_start_import (EShellWindow *shell_window)
 	GtkWidget *html;
 	static gboolean dialog_open = FALSE;
 	GdkPixbuf *icon;
-	char *gladefile;
+	gchar *gladefile;
 
 	if (dialog_open) {
 		return;
@@ -755,7 +754,6 @@ e_shell_importer_start_import (EShellWindow *shell_window)
 
 	gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (data->intelligent)->vbox), data->importerpage->vbox, TRUE, TRUE, 0);
 
-
 	/* File selection and file type page */
 	data->filedialog = glade_xml_get_widget (data->wizard, "page2-file");
 	gnome_druid_page_standard_set_logo (GNOME_DRUID_PAGE_STANDARD (data->filedialog), icon);
