@@ -23,7 +23,6 @@
  * time field with popups for entering a date.
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -113,10 +112,8 @@ enum {
 	LAST_SIGNAL
 };
 
-
 static gint date_edit_signals [LAST_SIGNAL] = { 0 };
 
-
 static void e_date_edit_class_init		(EDateEditClass	*class);
 static void e_date_edit_init			(EDateEdit	*dedit);
 static void create_children			(EDateEdit	*dedit);
@@ -191,7 +188,6 @@ static gboolean e_date_edit_set_time_internal	(EDateEdit	*dedit,
 						 gint		 hour,
 						 gint		 minute);
 
-
 static GtkHBoxClass *parent_class;
 
 /**
@@ -223,7 +219,6 @@ e_date_edit_get_type		(void)
 	return date_edit_type;
 }
 
-
 static void
 e_date_edit_class_init		(EDateEditClass	*class)
 {
@@ -249,7 +244,6 @@ e_date_edit_class_init		(EDateEditClass	*class)
 	class->changed = NULL;
 }
 
-
 static void
 e_date_edit_init		(EDateEdit	*dedit)
 {
@@ -282,7 +276,6 @@ e_date_edit_init		(EDateEdit	*dedit)
 	e_date_edit_set_time (dedit, 0);
 }
 
-
 /**
  * e_date_edit_new:
  *
@@ -304,7 +297,6 @@ e_date_edit_new			(void)
 	return GTK_WIDGET (dedit);
 }
 
-
 static void
 create_children			(EDateEdit	*dedit)
 {
@@ -480,7 +472,6 @@ create_children			(EDateEdit	*dedit)
 			  G_CALLBACK (on_date_popup_none_button_clicked), dedit);
 }
 
-
 static void
 e_date_edit_dispose		(GObject	*object)
 {
@@ -504,7 +495,6 @@ e_date_edit_dispose		(GObject	*object)
 		(* G_OBJECT_CLASS (parent_class)->dispose) (object);
 }
 
-
 /* GtkWidget::mnemonic_activate() handler for the EDateEdit */
 static gboolean
 e_date_edit_mnemonic_activate (GtkWidget *widget, gboolean group_cycling)
@@ -530,7 +520,6 @@ e_date_edit_grab_focus		(GtkWidget	*widget)
 		gtk_widget_grab_focus (GTK_BIN (dedit->priv->time_combo)->child);
 }
 
-
 /**
  * e_date_edit_set_editable:
  * @dedit: an #EDateEdit widget.
@@ -553,7 +542,6 @@ e_date_edit_set_editable (EDateEdit *dedit, gboolean editable)
 	gtk_widget_set_sensitive (priv->date_button, editable);
 }
 
-
 /**
  * e_date_edit_get_time:
  * @dedit: an #EDateEdit widget.
@@ -600,7 +588,6 @@ e_date_edit_get_time		(EDateEdit	*dedit)
 	return mktime (&tmp_tm);
 }
 
-
 /**
  * e_date_edit_set_time:
  * @dedit: the EDateEdit widget
@@ -664,7 +651,6 @@ e_date_edit_set_time		(EDateEdit	*dedit,
 			       date_edit_signals [CHANGED], 0);
 }
 
-
 /**
  * e_date_edit_get_date:
  * @dedit: an #EDateEdit widget.
@@ -701,7 +687,6 @@ e_date_edit_get_date		(EDateEdit	*dedit,
 	return TRUE;
 }
 
-
 /**
  * e_date_edit_set_date:
  * @dedit: an #EDateEdit widget.
@@ -734,7 +719,6 @@ e_date_edit_set_date		(EDateEdit	*dedit,
 			       date_edit_signals [CHANGED], 0);
 }
 
-
 /**
  * e_date_edit_get_time_of_day:
  * @dedit: an #EDateEdit widget.
@@ -769,7 +753,6 @@ e_date_edit_get_time_of_day		(EDateEdit	*dedit,
 	}
 }
 
-
 /**
  * e_date_edit_set_time_of_day:
  * @dedit: an #EDateEdit widget.
@@ -854,7 +837,6 @@ e_date_edit_get_show_date		(EDateEdit	*dedit)
 	return dedit->priv->show_date;
 }
 
-
 /**
  * e_date_edit_set_show_date:
  * @dedit: an #EDateEdit widget.
@@ -895,7 +877,6 @@ e_date_edit_set_show_date		(EDateEdit	*dedit,
 		gtk_widget_hide (priv->space);
 }
 
-
 /**
  * e_date_edit_get_show_time:
  * @dedit: an #EDateEdit widget
@@ -911,7 +892,6 @@ e_date_edit_get_show_time		(EDateEdit	*dedit)
 	return dedit->priv->show_time;
 }
 
-
 /**
  * e_date_edit_set_show_time:
  * @dedit: an #EDateEdit widget
@@ -938,7 +918,6 @@ e_date_edit_set_show_time		(EDateEdit	*dedit,
 	e_date_edit_update_time_combo_state (dedit);
 }
 
-
 /**
  * e_date_edit_get_make_time_insensitive:
  * @dedit: an #EDateEdit widget
@@ -956,7 +935,6 @@ e_date_edit_get_make_time_insensitive	(EDateEdit	*dedit)
 	return dedit->priv->make_time_insensitive;
 }
 
-
 /**
  * e_date_edit_set_make_time_insensitive:
  * @dedit: an #EDateEdit widget
@@ -988,7 +966,6 @@ e_date_edit_set_make_time_insensitive	(EDateEdit	*dedit,
 	e_date_edit_update_time_combo_state (dedit);
 }
 
-
 /**
  * e_date_edit_get_week_start_day:
  * @dedit: an #EDateEdit widget
@@ -1011,7 +988,6 @@ e_date_edit_get_week_start_day		(EDateEdit	*dedit)
 	return week_start_day;
 }
 
-
 /**
  * e_date_edit_set_week_start_day:
  * @dedit: an #EDateEdit widget
@@ -1030,7 +1006,6 @@ e_date_edit_set_week_start_day		(EDateEdit	*dedit,
 			NULL);
 }
 
-
 /* Whether we show week numbers in the date popup. */
 gboolean
 e_date_edit_get_show_week_numbers	(EDateEdit	*dedit)
@@ -1046,7 +1021,6 @@ e_date_edit_get_show_week_numbers	(EDateEdit	*dedit)
 	return show_week_numbers;
 }
 
-
 void
 e_date_edit_set_show_week_numbers	(EDateEdit	*dedit,
 					 gboolean	 show_week_numbers)
@@ -1058,7 +1032,6 @@ e_date_edit_set_show_week_numbers	(EDateEdit	*dedit,
 			NULL);
 }
 
-
 /* Whether we use 24 hour format in the time field & popup. */
 gboolean
 e_date_edit_get_use_24_hour_format	(EDateEdit	*dedit)
@@ -1068,7 +1041,6 @@ e_date_edit_get_use_24_hour_format	(EDateEdit	*dedit)
 	return dedit->priv->use_24_hour_format;
 }
 
-
 void
 e_date_edit_set_use_24_hour_format	(EDateEdit	*dedit,
 					 gboolean	 use_24_hour_format)
@@ -1085,7 +1057,6 @@ e_date_edit_set_use_24_hour_format	(EDateEdit	*dedit,
 	e_date_edit_update_time_entry (dedit);
 }
 
-
 /* Whether we allow the date to be set to 'None'. e_date_edit_get_time() will
    return (time_t) -1 in this case. */
 gboolean
@@ -1096,7 +1067,6 @@ e_date_edit_get_allow_no_date_set	(EDateEdit	*dedit)
 	return GTK_WIDGET_VISIBLE (dedit->priv->none_button);
 }
 
-
 void
 e_date_edit_set_allow_no_date_set	(EDateEdit	*dedit,
 					 gboolean	 allow_no_date_set)
@@ -1121,7 +1091,6 @@ e_date_edit_set_allow_no_date_set	(EDateEdit	*dedit,
 	}
 }
 
-
 /* The range of time to show in the time combo popup. */
 void
 e_date_edit_get_time_popup_range	(EDateEdit	*dedit,
@@ -1134,7 +1103,6 @@ e_date_edit_get_time_popup_range	(EDateEdit	*dedit,
 	*upper_hour = dedit->priv->upper_hour;
 }
 
-
 void
 e_date_edit_set_time_popup_range	(EDateEdit	*dedit,
 					 gint		 lower_hour,
@@ -1161,7 +1129,6 @@ e_date_edit_set_time_popup_range	(EDateEdit	*dedit,
 	e_date_edit_update_time_entry (dedit);
 }
 
-
 /* The arrow button beside the date field has been clicked, so we show the
    popup with the ECalendar in. */
 static void
@@ -1171,7 +1138,6 @@ on_date_button_clicked		(GtkWidget	*widget,
 	e_date_edit_show_date_popup (dedit);
 }
 
-
 static void
 e_date_edit_show_date_popup	(EDateEdit	*dedit)
 {
@@ -1217,7 +1183,6 @@ e_date_edit_show_date_popup	(EDateEdit	*dedit)
 	gdk_window_focus (priv->cal_popup->window, GDK_CURRENT_TIME);
 }
 
-
 /* This positions the date popup below and to the left of the arrow button,
    just before it is shown. */
 static void
@@ -1256,7 +1221,6 @@ position_date_popup		(EDateEdit	*dedit)
 	gtk_window_move (GTK_WINDOW (dedit->priv->cal_popup), x, y);
 }
 
-
 /* A date has been selected in the date popup, so we set the date field
    and hide the popup. */
 static void
@@ -1275,7 +1239,6 @@ on_date_popup_date_selected	(ECalendarItem	*calitem,
 			      g_date_get_day (&start_date));
 }
 
-
 static void
 on_date_popup_now_button_clicked	(GtkWidget	*button,
 					 EDateEdit	*dedit)
@@ -1284,7 +1247,6 @@ on_date_popup_now_button_clicked	(GtkWidget	*button,
 	e_date_edit_set_time (dedit, 0);
 }
 
-
 static void
 on_date_popup_today_button_clicked	(GtkWidget	*button,
 					 EDateEdit	*dedit)
@@ -1308,7 +1270,6 @@ on_date_popup_today_button_clicked	(GtkWidget	*button,
 			      tmp_tm.tm_mon + 1, tmp_tm.tm_mday);
 }
 
-
 static void
 on_date_popup_none_button_clicked	(GtkWidget	*button,
 					 EDateEdit	*dedit)
@@ -1317,7 +1278,6 @@ on_date_popup_none_button_clicked	(GtkWidget	*button,
 	e_date_edit_set_time (dedit, -1);
 }
 
-
 /* A key has been pressed while the date popup is showing. If it is the Escape
    key we hide the popup. */
 static gint
@@ -1336,7 +1296,6 @@ on_date_popup_key_press			(GtkWidget	*widget,
 	return TRUE;
 }
 
-
 /* A mouse button has been pressed while the date popup is showing.
    Any button press events used to select days etc. in the popup will have
    have been handled elsewhere, so here we just hide the popup.
@@ -1373,7 +1332,6 @@ on_date_popup_button_press	(GtkWidget	*widget,
 	return TRUE;
 }
 
-
 /* A delete event has been received for the date popup, so we hide it and
    return TRUE so it doesn't get destroyed. */
 static gint
@@ -1384,7 +1342,6 @@ on_date_popup_delete_event	(GtkWidget	*widget,
 	return TRUE;
 }
 
-
 /* Hides the date popup, removing any grabs. */
 static void
 hide_date_popup			(EDateEdit	*dedit)
@@ -1395,7 +1352,6 @@ hide_date_popup			(EDateEdit	*dedit)
 	gdk_keyboard_ungrab (GDK_CURRENT_TIME);
 }
 
-
 /* Clears the time popup and rebuilds it using the lower_hour, upper_hour
    and use_24_hour_format settings. */
 static void
@@ -1451,7 +1407,6 @@ rebuild_time_popup			(EDateEdit	*dedit)
 	}
 }
 
-
 static gboolean
 e_date_edit_parse_date (EDateEdit *dedit,
 			const gchar *date_text,
@@ -1475,7 +1430,6 @@ e_date_edit_parse_date (EDateEdit *dedit,
 	return TRUE;
 }
 
-
 static gboolean
 e_date_edit_parse_time	(EDateEdit	*dedit,
 			 const gchar	*time_text,
@@ -1493,7 +1447,6 @@ e_date_edit_parse_time	(EDateEdit	*dedit,
 	return TRUE;
 }
 
-
 /* Returns TRUE if the string is empty or is "None" in the current locale.
    It ignores whitespace. */
 static gboolean
@@ -1514,7 +1467,6 @@ field_set_to_none (const gchar *text)
 	return FALSE;
 }
 
-
 static void
 on_date_edit_time_selected	(GtkComboBox	*combo,
 				 EDateEdit	*dedit)
@@ -1530,7 +1482,6 @@ on_date_edit_time_selected	(GtkComboBox	*combo,
 	e_date_edit_check_time_changed (dedit);
 }
 
-
 static gint
 on_date_entry_key_press			(GtkWidget	*widget,
 					 GdkEventKey	*event,
@@ -1555,7 +1506,6 @@ on_date_entry_key_press			(GtkWidget	*widget,
 	return FALSE;
 }
 
-
 static gint
 on_time_entry_key_press			(GtkWidget	*widget,
 					 GdkEventKey	*event,
@@ -1611,7 +1561,6 @@ on_time_entry_key_release		(GtkWidget	*widget,
 	return FALSE;
 }
 
-
 static gint
 on_date_entry_focus_out			(GtkEntry	*entry,
 					 GdkEventFocus  *event,
@@ -1647,7 +1596,6 @@ on_date_entry_focus_out			(GtkEntry	*entry,
 	return FALSE;
 }
 
-
 static gint
 on_time_entry_focus_out			(GtkEntry	*entry,
 					 GdkEventFocus  *event,
@@ -1729,12 +1677,18 @@ e_date_edit_update_date_entry		(EDateEdit	*dedit)
 		   %x the preferred date representation for the current locale without the time,
 		   but has forced to use 4 digit year */
 		gchar *format = e_time_get_d_fmt_with_4digit_year ();
+		time_t tt;
 
 		tmp_tm.tm_year = priv->year;
 		tmp_tm.tm_mon = priv->month;
 		tmp_tm.tm_mday = priv->day;
 		tmp_tm.tm_isdst = -1;
 
+		/* initialize all 'struct tm' members properly */
+		tt = mktime (&tmp_tm);
+		if (tt && localtime (&tt))
+			tmp_tm = *localtime (&tt);
+
 		e_utf8_strftime (buffer, sizeof (buffer), format, &tmp_tm);
 		g_free (format);
 		gtk_entry_set_text (GTK_ENTRY (priv->date_entry), buffer);
@@ -1744,7 +1698,6 @@ e_date_edit_update_date_entry		(EDateEdit	*dedit)
 	add_relation (dedit, priv->date_button);
 }
 
-
 /* This sets the text in the time entry according to the current settings. */
 static void
 e_date_edit_update_time_entry		(EDateEdit	*dedit)
@@ -1821,7 +1774,6 @@ e_date_edit_update_time_entry		(EDateEdit	*dedit)
 	add_relation (dedit, priv->time_combo);
 }
 
-
 static void
 e_date_edit_update_time_combo_state	(EDateEdit	*dedit)
 {
@@ -1876,7 +1828,6 @@ e_date_edit_update_time_combo_state	(EDateEdit	*dedit)
 		gtk_widget_hide (priv->space);
 }
 
-
 /* Parses the date, and if it is different from the current settings it
    updates the settings and emits a "date_changed" signal. */
 static void
@@ -1903,7 +1854,6 @@ e_date_edit_check_date_changed		(EDateEdit	*dedit)
 		tmp_tm.tm_mday = 0;
 	}
 
-
 	date_changed = e_date_edit_set_date_internal (dedit, valid, none,
 						      tmp_tm.tm_year,
 						      tmp_tm.tm_mon,
@@ -1914,7 +1864,6 @@ e_date_edit_check_date_changed		(EDateEdit	*dedit)
 			       date_edit_signals [CHANGED], 0);
 }
 
-
 /* Parses the time, and if it is different from the current settings it
    updates the settings and emits a "time_changed" signal. */
 static void
@@ -1947,7 +1896,6 @@ e_date_edit_check_time_changed		(EDateEdit	*dedit)
 	}
 }
 
-
 /**
  * e_date_edit_date_is_valid:
  * @dedit: an #EDateEdit widget.
@@ -1975,7 +1923,6 @@ e_date_edit_date_is_valid	(EDateEdit	*dedit)
 	return TRUE;
 }
 
-
 /**
  * e_date_edit_time_is_valid:
  * @dedit: an #EDateEdit widget.
@@ -2066,7 +2013,6 @@ e_date_edit_set_date_internal	(EDateEdit	*dedit,
 	return date_changed;
 }
 
-
 static gboolean
 e_date_edit_set_time_internal	(EDateEdit	*dedit,
 				 gboolean	 valid,
