@@ -1,21 +1,25 @@
-/* Evolution calendar - Main page of the Groupwise send options Dialog
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- * Authors: Chenthill Palanisamy <pchenthill@novell.com>
+/*
+ * Evolution calendar - Main page of the Groupwise send options Dialog
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Chenthill Palanisamy <pchenthill@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -23,17 +27,16 @@
 #endif
 
 #include <string.h>
-#include <libgnome/libgnome.h>
 #include <glib/gi18n.h>
 #include <glade/glade.h>
 #include <time.h>
 
+#include "e-util/e-util.h"
 #include "e-util/e-util-private.h"
 
 #include "e-dateedit.h"
 #include "e-send-options.h"
 
-
 struct _ESendOptionsDialogPrivate {
 	/* Glade XML data */
 	GladeXML *xml;
@@ -93,7 +96,7 @@ struct _ESendOptionsDialogPrivate {
 	GtkWidget *accepted_label;
 	GtkWidget *completed_label;
 	GtkWidget *until_label;
-        char *help_section;
+        gchar *help_section;
 };
 
 static void e_sendoptions_dialog_class_init (GObjectClass *object_class);
@@ -341,7 +344,7 @@ delay_until_date_changed_cb (GtkWidget *dedit, gpointer data)
 
 }
 static void
-page_changed_cb (GtkNotebook *notebook, GtkNotebookPage *page, int num, gpointer data)
+page_changed_cb (GtkNotebook *notebook, GtkNotebookPage *page, gint num, gpointer data)
 {
 	ESendOptionsDialog *sod = data;
 	ESendOptionsDialogPrivate *priv = sod->priv;
@@ -376,7 +379,6 @@ page_changed_cb (GtkNotebook *notebook, GtkNotebookPage *page, int num, gpointer
 	e_send_options_fill_widgets_with_data (sod);
 }
 
-
 static void
 init_widgets (ESendOptionsDialog *sod)
 {
@@ -393,8 +395,7 @@ init_widgets (ESendOptionsDialog *sod)
 	g_signal_connect (priv->delay_until, "changed", G_CALLBACK (delay_until_date_changed_cb), sod);
 
 	if (priv->global)
-	 	g_signal_connect (priv->notebook, "switch-page", G_CALLBACK (page_changed_cb), sod);
-
+		g_signal_connect (priv->notebook, "switch-page", G_CALLBACK (page_changed_cb), sod);
 
 }
 
@@ -498,7 +499,7 @@ setup_widgets (ESendOptionsDialog *sod, Item_type type)
 	gtk_label_set_mnemonic_widget (GTK_LABEL (priv->until_label), priv->delay_until);
 
 	if (priv->global) {
-	        GtkWidget *widget = gtk_label_new ("Calendar");
+		GtkWidget *widget = gtk_label_new ("Calendar");
 		gtk_label_set_text (GTK_LABEL (priv->sopts_label), "Mail");
 		gtk_notebook_append_page (priv->notebook, priv->status, widget);
 		gtk_widget_show (widget);
@@ -510,7 +511,7 @@ setup_widgets (ESendOptionsDialog *sod, Item_type type)
 
 	switch (type) {
 		case E_ITEM_MAIL:
-		        priv->help_section = g_strdup ("usage-mail");
+			priv->help_section = g_strdup ("usage-mail");
 			gtk_widget_hide (priv->accepted_label);
 			gtk_widget_hide (priv->when_accepted);
 			gtk_widget_hide (priv->completed_label);
@@ -518,11 +519,11 @@ setup_widgets (ESendOptionsDialog *sod, Item_type type)
 			gtk_label_set_text_with_mnemonic (GTK_LABEL (priv->declined_label), (_("When de_leted:")));
 			break;
 		case E_ITEM_CALENDAR:
-         	        priv->help_section = g_strdup ("usage-calendar");
+			priv->help_section = g_strdup ("usage-calendar");
 			gtk_widget_hide (priv->completed_label);
 			gtk_widget_hide (priv->when_completed);
 		case E_ITEM_TASK:
-		        priv->help_section = g_strdup ("usage-calendar-todo");
+			priv->help_section = g_strdup ("usage-calendar-todo");
 			gtk_widget_hide (priv->security_label);
 			gtk_widget_hide (priv->security);
 			gtk_widget_set_sensitive (priv->autodelete, FALSE);
@@ -586,7 +587,6 @@ static void e_send_options_cb (GtkDialog *dialog, gint state, gpointer func_data
 {
 	ESendOptionsDialogPrivate *priv;
 	ESendOptionsDialog *sod;
-	GError *error = NULL;
 
 	sod = func_data;
 	priv = sod->priv;
@@ -600,13 +600,10 @@ static void e_send_options_cb (GtkDialog *dialog, gint state, gpointer func_data
 			g_object_unref (priv->xml);
 			break;
 		case GTK_RESPONSE_HELP:
-			gnome_help_display (
-				"evolution.xml", priv->help_section, &error);
-			if (error != NULL) {
-				g_warning ("%s", error->message);
-				g_error_free (error);
-			}
-    			break;
+			e_display_help (
+				GTK_WINDOW (priv->main),
+				priv->help_section);
+			break;
 	}
 
 	g_signal_emit (G_OBJECT (func_data), signals[SOD_RESPONSE], 0, state);
@@ -733,7 +730,6 @@ e_sendoptions_dialog_init (GObject *object)
 	ESendOptionsDialogPrivate *priv;
 	ESendOptionsData *new;
 
-
 	sod = E_SENDOPTIONS_DIALOG (object);
 	new = g_new0 (ESendOptionsData, 1);
 	new->gopts = g_new0 (ESendOptionsGeneral, 1);
@@ -821,7 +817,7 @@ GType e_sendoptions_dialog_get_type (void)
       sizeof (ESendOptionsDialog),
      0,      /* n_preallocs */
      (GInstanceInitFunc) e_sendoptions_dialog_init,
- 	NULL    /* instance_init */
+	NULL    /* instance_init */
     };
     type = g_type_register_static (G_TYPE_OBJECT,
                                    "ESendOptionsDialogType",
