@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -101,7 +101,7 @@ e_table_group_new (GnomeCanvasGroup *parent,
 		   ETableHeader     *header,
 		   ETableModel      *model,
 		   ETableSortInfo   *sort_info,
-		   int               n)
+		   gint               n)
 {
 	g_return_val_if_fail (model != NULL, NULL);
 
@@ -170,8 +170,8 @@ e_table_group_add (ETableGroup *etg,
  */
 void
 e_table_group_add_array (ETableGroup *etg,
-			 const int *array,
-			 int count)
+			 const gint *array,
+			 gint count)
 {
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
@@ -372,7 +372,7 @@ e_table_group_get_printable (ETableGroup *etg)
  * %ETableGroup is removed from the value y points to.
  */
 void
-e_table_group_compute_location (ETableGroup *etg, int *x, int *y, int *row, int *col)
+e_table_group_compute_location (ETableGroup *etg, gint *x, gint *y, gint *row, gint *col)
 {
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
@@ -382,7 +382,7 @@ e_table_group_compute_location (ETableGroup *etg, int *x, int *y, int *row, int
 }
 
 void
-e_table_group_get_mouse_over (ETableGroup *etg, int *row, int *col)
+e_table_group_get_mouse_over (ETableGroup *etg, gint *row, gint *col)
 {
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
@@ -407,12 +407,12 @@ e_table_group_get_mouse_over (ETableGroup *etg, int *row, int *col)
  */
 void
 e_table_group_get_cell_geometry  (ETableGroup *etg,
-				  int         *row,
-				  int         *col,
-				  int         *x,
-				  int         *y,
-				  int         *width,
-				  int         *height)
+				  gint         *row,
+				  gint         *col,
+				  gint         *x,
+				  gint         *y,
+				  gint         *width,
+				  gint         *height)
 {
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
@@ -590,7 +590,7 @@ e_table_group_get_header (ETableGroup *etg)
 	return etg->header;
 }
 
-static int
+static gint
 etg_event (GnomeCanvasItem *item, GdkEvent *event)
 {
 	ETableGroup *etg = E_TABLE_GROUP (item);
@@ -675,7 +675,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, double_click),
 			      NULL, NULL,
-			      e_util_marshal_NONE__INT_INT_BOXED,
+			      e_marshal_NONE__INT_INT_BOXED,
 			      G_TYPE_NONE, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 
@@ -685,7 +685,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, right_click),
 			      NULL, NULL,
-			      e_util_marshal_INT__INT_INT_BOXED,
+			      e_marshal_INT__INT_INT_BOXED,
 			      G_TYPE_INT, 3, G_TYPE_INT, G_TYPE_INT, GDK_TYPE_EVENT);
 
 	etg_signals [CLICK] =
@@ -694,7 +694,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, click),
 			      NULL, NULL,
-			      e_util_marshal_INT__INT_INT_BOXED,
+			      e_marshal_INT__INT_INT_BOXED,
 			      G_TYPE_INT, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 
@@ -704,7 +704,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, key_press),
 			      NULL, NULL,
-			      e_util_marshal_INT__INT_INT_BOXED,
+			      e_marshal_INT__INT_INT_BOXED,
 			      G_TYPE_INT, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 
@@ -714,7 +714,7 @@ etg_class_init (ETableGroupClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ETableGroupClass, start_drag),
 			      NULL, NULL,
-			      e_util_marshal_INT__INT_INT_BOXED,
+			      e_marshal_INT__INT_INT_BOXED,
 			      G_TYPE_INT, 3, G_TYPE_INT,
 			      G_TYPE_INT, GDK_TYPE_EVENT);
 }
