@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -35,7 +35,6 @@
 #include <gdk/gdkkeysyms.h>
 
 #include <glib/gi18n.h>
-#include "e-util/e-util-marshal.h"
 #include "e-util/e-util.h"
 #include "e-util/e-xml-utils.h"
 #include "misc/e-canvas.h"
@@ -152,12 +151,12 @@ ethi_dispose (GObject *object){
 		(*G_OBJECT_CLASS (ethi_parent_class)->dispose) (object);
 }
 
-static int
+static gint
 e_table_header_item_get_height (ETableHeaderItem *ethi)
 {
 	ETableHeader *eth;
-	int numcols, col;
-	int maxheight;
+	gint numcols, col;
+	gint maxheight;
 
 	g_return_val_if_fail (ethi != NULL, 0);
 	g_return_val_if_fail (E_IS_TABLE_HEADER_ITEM (ethi), 0);
@@ -169,7 +168,7 @@ e_table_header_item_get_height (ETableHeaderItem *ethi)
 
 	for (col = 0; col < numcols; col++) {
 		ETableCol *ecol = e_table_header_get_column (eth, col);
-		int height;
+		gint height;
 
 		height = e_table_header_compute_height (ecol,
 							GTK_WIDGET (GNOME_CANVAS_ITEM (ethi)->canvas));
@@ -182,7 +181,7 @@ e_table_header_item_get_height (ETableHeaderItem *ethi)
 }
 
 static void
-ethi_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, int flags)
+ethi_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, gint flags)
 {
 	ETableHeaderItem *ethi = E_TABLE_HEADER_ITEM (item);
 
@@ -261,7 +260,7 @@ structure_changed (ETableHeader *header, ETableHeaderItem *ethi)
 }
 
 static void
-dimension_changed (ETableHeader *header, int col, ETableHeaderItem *ethi)
+dimension_changed (ETableHeader *header, gint col, ETableHeaderItem *ethi)
 {
 	gnome_canvas_item_request_update(GNOME_CANVAS_ITEM(ethi));
 }
@@ -388,12 +387,12 @@ ethi_get_property (GObject *object,
 	}
 }
 
-static int
-ethi_find_col_by_x (ETableHeaderItem *ethi, int x)
+static gint
+ethi_find_col_by_x (ETableHeaderItem *ethi, gint x)
 {
-	const int cols = e_table_header_count (ethi->eth);
-	int x1 = 0;
-	int col;
+	const gint cols = e_table_header_count (ethi->eth);
+	gint x1 = 0;
+	gint col;
 
 	d(g_print ("%s:%d: x = %d, x1 = %d\n", __FUNCTION__, __LINE__, x, x1));
 
@@ -418,12 +417,12 @@ ethi_find_col_by_x (ETableHeaderItem *ethi, int x)
 	return cols - 1;
 }
 
-static int
-ethi_find_col_by_x_nearest (ETableHeaderItem *ethi, int x)
+static gint
+ethi_find_col_by_x_nearest (ETableHeaderItem *ethi, gint x)
 {
-	const int cols = e_table_header_count (ethi->eth);
-	int x1 = 0;
-	int col;
+	const gint cols = e_table_header_count (ethi->eth);
+	gint x1 = 0;
+	gint col;
 
 	x1 += ethi->group_indent_width;
 
@@ -456,7 +455,7 @@ ethi_remove_drop_marker (ETableHeaderItem *ethi)
 }
 
 static GtkWidget *
-make_shaped_window_from_xpm (const char **xpm)
+make_shaped_window_from_xpm (const gchar **xpm)
 {
 	GdkPixbuf *pixbuf;
 	GdkPixmap *pixmap;
@@ -484,10 +483,10 @@ make_shaped_window_from_xpm (const char **xpm)
 }
 
 static void
-ethi_add_drop_marker (ETableHeaderItem *ethi, int col, gboolean recreate)
+ethi_add_drop_marker (ETableHeaderItem *ethi, gint col, gboolean recreate)
 {
-	int rx, ry;
-	int x;
+	gint rx, ry;
+	gint x;
 
 	if (!recreate && ethi->drag_mark == col)
 		return;
@@ -510,16 +509,16 @@ ethi_add_drop_marker (ETableHeaderItem *ethi, int col, gboolean recreate)
 	rx -= gtk_layout_get_hadjustment (GTK_LAYOUT (GNOME_CANVAS_ITEM (ethi)->canvas))->value;
 	ry -= gtk_layout_get_vadjustment (GTK_LAYOUT (GNOME_CANVAS_ITEM (ethi)->canvas))->value;
 
-	gtk_widget_set_uposition (arrow_down, rx + x - ARROW_PTR, ry - ARROW_DOWN_HEIGHT);
+	gtk_window_move (GTK_WINDOW (arrow_down), rx + x - ARROW_PTR, ry - ARROW_DOWN_HEIGHT);
 	gtk_widget_show_all (arrow_down);
 
-	gtk_widget_set_uposition (arrow_up, rx + x - ARROW_PTR, ry + ethi->height);
+	gtk_window_move (GTK_WINDOW (arrow_up), rx + x - ARROW_PTR, ry + ethi->height);
 	gtk_widget_show_all (arrow_up);
 }
 
 #define gray50_width    2
 #define gray50_height   2
-static char gray50_bits [] = {
+static gchar gray50_bits [] = {
   0x02, 0x01, };
 
 static void
@@ -593,7 +592,7 @@ do_drag_motion(ETableHeaderItem *ethi,
 
 	if ((x >= 0) && (x <= (ethi->width)) &&
 	    (y >= 0) && (y <= (ethi->height))){
-		int col;
+		gint col;
 		d(g_print("In header\n"));
 
 		col = ethi_find_col_by_x_nearest (ethi, x);
@@ -627,7 +626,7 @@ static gboolean
 scroll_timeout (gpointer data)
 {
 	ETableHeaderItem *ethi = data;
-	int dx = 0;
+	gint dx = 0;
 	GtkAdjustment *h, *v;
 	double value;
 
@@ -702,7 +701,7 @@ ethi_drag_motion (GtkWidget *widget, GdkDragContext *context,
 		  gint x, gint y, guint time,
 		  ETableHeaderItem *ethi)
 {
-	char *droptype, *headertype;
+	gchar *droptype, *headertype;
 	guint direction = 0;
 
 	gdk_drag_status (context, 0, time);
@@ -769,15 +768,15 @@ ethi_drag_data_received (GtkWidget *canvas,
 			 guint time,
 			 ETableHeaderItem *ethi)
 {
-	int found = FALSE;
-	int count;
-	int column;
-	int drop_col;
-	int i;
+	gint found = FALSE;
+	gint count;
+	gint column;
+	gint drop_col;
+	gint i;
 
 	if (data->data) {
 		count = e_table_header_count(ethi->eth);
-		column = atoi((char *)data->data);
+		column = atoi((gchar *)data->data);
 		drop_col = ethi->drop_col;
 		ethi->drop_col = -1;
 
@@ -821,7 +820,7 @@ ethi_drag_data_get (GtkWidget *canvas,
 		gtk_selection_data_set(selection_data,
 				       GDK_SELECTION_TYPE_STRING,
 				       sizeof(string[0]),
-				       (unsigned char *)string,
+				       (guchar *)string,
 				       strlen(string));
 		g_free(string);
 	}
@@ -839,7 +838,7 @@ ethi_drag_drop (GtkWidget *canvas,
 
 	if ((x >= 0) && (x <= (ethi->width)) &&
 	    (y >= 0) && (y <= (ethi->height))){
-		int col;
+		gint col;
 
 		col = ethi_find_col_by_x_nearest (ethi, x);
 
@@ -848,7 +847,7 @@ ethi_drag_drop (GtkWidget *canvas,
 		ethi->drop_col = col;
 
 		if (col != -1) {
-			char *target = g_strdup_printf ("%s-%s", TARGET_ETABLE_COL_TYPE, ethi->dnd_code);
+			gchar *target = g_strdup_printf ("%s-%s", TARGET_ETABLE_COL_TYPE, ethi->dnd_code);
 			d(g_print ("ethi -  %s\n", target));
 			gtk_drag_get_data (canvas, context, gdk_atom_intern(target, FALSE), time);
 			g_free (target);
@@ -872,10 +871,9 @@ ethi_realize (GnomeCanvasItem *item)
 {
 	ETableHeaderItem *ethi = E_TABLE_HEADER_ITEM (item);
 	GtkTargetEntry  ethi_drop_types [] = {
-		{ TARGET_ETABLE_COL_TYPE, 0, TARGET_ETABLE_COL_HEADER },
+		{ (gchar *) TARGET_ETABLE_COL_TYPE, 0, TARGET_ETABLE_COL_HEADER },
 	};
 
-
 	if (GNOME_CANVAS_ITEM_CLASS (ethi_parent_class)-> realize)
 		(*GNOME_CANVAS_ITEM_CLASS (ethi_parent_class)->realize)(item);
 
@@ -889,7 +887,7 @@ ethi_realize (GnomeCanvasItem *item)
 	gtk_drag_dest_set (GTK_WIDGET (item->canvas), 0,
 			   ethi_drop_types, ELEMENTS (ethi_drop_types),
 			   GDK_ACTION_MOVE);
-  	g_free(ethi_drop_types[0].target);
+	g_free(ethi_drop_types[0].target);
 
 	/* Drop signals */
 	ethi->drag_motion_id = g_signal_connect (item->canvas, "drag_motion",
@@ -936,19 +934,18 @@ ethi_unrealize (GnomeCanvasItem *item)
 }
 
 static void
-ethi_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int width, int height)
+ethi_draw (GnomeCanvasItem *item, GdkDrawable *drawable, gint x, gint y, gint width, gint height)
 {
 	ETableHeaderItem *ethi = E_TABLE_HEADER_ITEM (item);
 	GnomeCanvas *canvas = item->canvas;
-	const int cols = e_table_header_count (ethi->eth);
-	int x1, x2;
-	int col;
+	const gint cols = e_table_header_count (ethi->eth);
+	gint x1, x2;
+	gint col;
 	GHashTable *arrows = g_hash_table_new (NULL, NULL);
 
-
 	if (ethi->sort_info) {
-		int length = e_table_sort_info_grouping_get_count(ethi->sort_info);
-		int i;
+		gint length = e_table_sort_info_grouping_get_count(ethi->sort_info);
+		gint i;
 		for (i = 0; i < length; i++) {
 			ETableSortColumn column = e_table_sort_info_grouping_get_nth(ethi->sort_info, i);
 			g_hash_table_insert (arrows,
@@ -973,7 +970,7 @@ ethi_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int width
 	x2 += ethi->group_indent_width;
 	for (col = 0; col < cols; col++, x1 = x2){
 		ETableCol *ecol = e_table_header_get_column (ethi->eth, col);
-		int col_width;
+		gint col_width;
 
 		col_width = ecol->width;
 
@@ -1003,7 +1000,7 @@ ethi_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int width
 }
 
 static double
-ethi_point (GnomeCanvasItem *item, double x, double y, int cx, int cy,
+ethi_point (GnomeCanvasItem *item, double x, double y, gint cx, gint cy,
 	    GnomeCanvasItem **actual_item)
 {
 	*actual_item = item;
@@ -1018,10 +1015,10 @@ ethi_point (GnomeCanvasItem *item, double x, double y, int cx, int cy,
  * then the ETableCol that actually contains this point is returned here
  */
 static gboolean
-is_pointer_on_division (ETableHeaderItem *ethi, int pos, int *the_total, int *return_col)
+is_pointer_on_division (ETableHeaderItem *ethi, gint pos, gint *the_total, gint *return_col)
 {
-	const int cols = e_table_header_count (ethi->eth);
-	int col, total;
+	const gint cols = e_table_header_count (ethi->eth);
+	gint col, total;
 
 	total = 0;
 	for (col = 0; col < cols; col++){
@@ -1053,9 +1050,9 @@ is_pointer_on_division (ETableHeaderItem *ethi, int pos, int *the_total, int *re
 #define convert(c,sx,sy,x,y) gnome_canvas_w2c (c,sx,sy,x,y)
 
 static void
-set_cursor (ETableHeaderItem *ethi, int pos)
+set_cursor (ETableHeaderItem *ethi, gint pos)
 {
-	int col;
+	gint col;
 	GtkWidget *canvas = GTK_WIDGET (GNOME_CANVAS_ITEM (ethi)->canvas);
 	gboolean resizable = FALSE;
 
@@ -1064,12 +1061,12 @@ set_cursor (ETableHeaderItem *ethi, int pos)
 		return;
 
 	if (is_pointer_on_division (ethi, pos, NULL, &col)) {
-		int last_col = ethi->eth->col_count - 1;
+		gint last_col = ethi->eth->col_count - 1;
 		ETableCol *ecol = e_table_header_get_column (ethi->eth, col);
 
 		/* Last column is not resizable */
 		if (ecol->resizable && col != last_col) {
-			int c = col + 1;
+			gint c = col + 1;
 
 			/* Column is not resizable if all columns after it
 			   are also not resizable */
@@ -1126,13 +1123,13 @@ ethi_start_drag (ETableHeaderItem *ethi, GdkEvent *event)
 	GtkTargetList *list;
 	GdkDragContext *context;
 	ETableCol *ecol;
-	int col_width;
+	gint col_width;
 	GdkPixmap *pixmap;
-	int group_indent = 0;
+	gint group_indent = 0;
 	GHashTable *arrows = g_hash_table_new (NULL, NULL);
 
 	GtkTargetEntry  ethi_drag_types [] = {
-		{ TARGET_ETABLE_COL_TYPE, 0, TARGET_ETABLE_COL_HEADER },
+		{ (gchar *) TARGET_ETABLE_COL_TYPE, 0, TARGET_ETABLE_COL_HEADER },
 	};
 
 	ethi->drag_col = ethi_find_col_by_x (ethi, event->motion.x);
@@ -1141,8 +1138,8 @@ ethi_start_drag (ETableHeaderItem *ethi, GdkEvent *event)
 		return;
 
 	if (ethi->sort_info) {
-		int length = e_table_sort_info_grouping_get_count(ethi->sort_info);
-		int i;
+		gint length = e_table_sort_info_grouping_get_count(ethi->sort_info);
+		gint i;
 		for (i = 0; i < length; i++) {
 			ETableSortColumn column =
 				e_table_sort_info_grouping_get_nth(
@@ -1206,17 +1203,17 @@ ethi_start_drag (ETableHeaderItem *ethi, GdkEvent *event)
 
 typedef struct {
 	ETableHeaderItem *ethi;
-	int col;
+	gint col;
 } EthiHeaderInfo;
 
 static void
 ethi_popup_sort_ascending(GtkWidget *widget, EthiHeaderInfo *info)
 {
 	ETableCol *col;
-	int model_col = -1;
-	int length;
-	int i;
-	int found = FALSE;
+	gint model_col = -1;
+	gint length;
+	gint i;
+	gint found = FALSE;
 	ETableHeaderItem *ethi = info->ethi;
 
 	col = e_table_header_get_column (ethi->eth, info->col);
@@ -1268,10 +1265,10 @@ static void
 ethi_popup_sort_descending(GtkWidget *widget, EthiHeaderInfo *info)
 {
 	ETableCol *col;
-	int model_col=-1;
-	int length;
-	int i;
-	int found = FALSE;
+	gint model_col=-1;
+	gint length;
+	gint i;
+	gint found = FALSE;
 	ETableHeaderItem *ethi = info->ethi;
 
 	col = e_table_header_get_column (ethi->eth, info->col);
@@ -1332,7 +1329,7 @@ static void
 ethi_popup_group_field(GtkWidget *widget, EthiHeaderInfo *info)
 {
 	ETableCol *col;
-	int model_col;
+	gint model_col;
 	ETableHeaderItem *ethi = info->ethi;
 	ETableSortColumn column;
 
@@ -1390,7 +1387,7 @@ static void
 ethi_popup_best_fit(GtkWidget *widget, EthiHeaderInfo *info)
 {
 	ETableHeaderItem *ethi = info->ethi;
-	int width;
+	gint width;
 
 	g_signal_emit_by_name (ethi->eth,
 			       "request_width",
@@ -1417,7 +1414,7 @@ config_destroyed (gpointer data, GObject *where_object_was)
 static void
 apply_changes (ETableConfig *config, ETableHeaderItem *ethi)
 {
-	char *state = e_table_state_save_to_string (config->state);
+	gchar *state = e_table_state_save_to_string (config->state);
 
 	if (ethi->table)
 		e_table_set_state (ethi->table, state);
@@ -1469,19 +1466,19 @@ free_popup_info (GtkWidget *w, EthiHeaderInfo *info)
 /* Bit 2 is disabled if not "sortable". */
 /* Bit 4 is disabled if we don't have a pointer to our table object. */
 static EPopupMenu ethi_context_menu [] = {
-	E_POPUP_ITEM (N_("Sort _Ascending"),            G_CALLBACK(ethi_popup_sort_ascending),  2),
-	E_POPUP_ITEM (N_("Sort _Descending"),           G_CALLBACK(ethi_popup_sort_descending), 2),
-	E_POPUP_ITEM (N_("_Unsort"),                    G_CALLBACK(ethi_popup_unsort),          0),
+	E_POPUP_ITEM (N_("Sort _Ascending"), G_CALLBACK(ethi_popup_sort_ascending),  2),
+	E_POPUP_ITEM (N_("Sort _Descending"), G_CALLBACK(ethi_popup_sort_descending), 2),
+	E_POPUP_ITEM (N_("_Unsort"), G_CALLBACK(ethi_popup_unsort),          0),
 	E_POPUP_SEPARATOR,
-	E_POPUP_ITEM (N_("Group By This _Field"),       G_CALLBACK(ethi_popup_group_field),     16),
-	E_POPUP_ITEM (N_("Group By _Box"),              G_CALLBACK(ethi_popup_group_box),       128),
+	E_POPUP_ITEM (N_("Group By This _Field"), G_CALLBACK(ethi_popup_group_field),     16),
+	E_POPUP_ITEM (N_("Group By _Box"), G_CALLBACK(ethi_popup_group_box),       128),
 	E_POPUP_SEPARATOR,
-	E_POPUP_ITEM (N_("Remove This _Column"),        G_CALLBACK(ethi_popup_remove_column),   8),
-	E_POPUP_ITEM (N_("Add a C_olumn..."),           G_CALLBACK(ethi_popup_field_chooser),   0),
+	E_POPUP_ITEM (N_("Remove This _Column"), G_CALLBACK(ethi_popup_remove_column),   8),
+	E_POPUP_ITEM (N_("Add a C_olumn..."), G_CALLBACK(ethi_popup_field_chooser),   0),
 	E_POPUP_SEPARATOR,
-	E_POPUP_ITEM (N_("A_lignment"),                 G_CALLBACK(ethi_popup_alignment),       128),
-	E_POPUP_ITEM (N_("B_est Fit"),                  G_CALLBACK(ethi_popup_best_fit),        2),
-	E_POPUP_ITEM (N_("Format Column_s..."),         G_CALLBACK(ethi_popup_format_columns),  128),
+	E_POPUP_ITEM (N_("A_lignment"), G_CALLBACK(ethi_popup_alignment),       128),
+	E_POPUP_ITEM (N_("B_est Fit"), G_CALLBACK(ethi_popup_best_fit),        2),
+	E_POPUP_ITEM (N_("Format Column_s..."), G_CALLBACK(ethi_popup_format_columns),  128),
 	E_POPUP_SEPARATOR,
 	E_POPUP_ITEM (N_("Custo_mize Current View..."), G_CALLBACK(ethi_popup_customize_view),  4),
 	E_POPUP_TERMINATOR
@@ -1490,7 +1487,7 @@ static EPopupMenu ethi_context_menu [] = {
 static void
 sort_by_id (GtkWidget *menu_item, ETableHeaderItem *ethi)
 {
-	int col = GPOINTER_TO_INT (g_object_get_data(G_OBJECT (menu_item), "col-number"));
+	gint col = GPOINTER_TO_INT (g_object_get_data(G_OBJECT (menu_item), "col-number"));
 	ETableCol *ecol;
 	gboolean clearfirst;
 
@@ -1521,7 +1518,7 @@ ethi_header_context_menu (ETableHeaderItem *ethi, GdkEventButton *event)
 	EthiHeaderInfo *info = g_new (EthiHeaderInfo, 1);
 	ETableCol *col;
 	GtkMenu *popup;
-	int ncol, sort_count, sort_col;
+	gint ncol, sort_count, sort_col;
 	GtkWidget *menu_item, *sub_menu;
 	ETableSortColumn column;
 	gboolean ascending = TRUE;
@@ -1572,7 +1569,7 @@ ethi_header_context_menu (ETableHeaderItem *ethi, GdkEventButton *event)
 	/* Headers */
 	for (ncol = 0; ncol<ethi->full_header->col_count; ncol++)
 	{
-		char *text=NULL;
+		gchar *text=NULL;
 
 		if (!ethi->full_header->columns[ncol]->sortable ||
 		    ethi->full_header->columns[ncol]->disabled)
@@ -1611,9 +1608,9 @@ ethi_button_pressed (ETableHeaderItem *ethi, GdkEventButton *event)
 void
 ethi_change_sort_state (ETableHeaderItem *ethi, ETableCol *col)
 {
-	int model_col = -1;
-	int length;
-	int i;
+	gint model_col = -1;
+	gint length;
+	gint i;
 	gboolean found = FALSE;
 
 	if (col == NULL)
@@ -1626,7 +1623,7 @@ ethi_change_sort_state (ETableHeaderItem *ethi, ETableCol *col)
 	for (i = 0; i < length; i++) {
 		ETableSortColumn column = e_table_sort_info_grouping_get_nth(ethi->sort_info, i);
 		if (model_col == column.column || model_col == -1){
-			int ascending = column.ascending;
+			gint ascending = column.ascending;
 			ascending = ! ascending;
 			column.ascending = ascending;
 			e_table_sort_info_grouping_set_nth(ethi->sort_info, i, column);
@@ -1642,14 +1639,14 @@ ethi_change_sort_state (ETableHeaderItem *ethi, ETableCol *col)
 			ETableSortColumn column = e_table_sort_info_sorting_get_nth(ethi->sort_info, i);
 
 			if (model_col == column.column || model_col == -1){
-				int ascending = column.ascending;
+				gint ascending = column.ascending;
 
 				if (ascending == 0 && model_col != -1){
 					/*
 					 * This means the user has clicked twice
 					 * already, lets kill sorting of this column now.
 					 */
-					int j;
+					gint j;
 
 					for (j = i + 1; j < length; j++)
 						e_table_sort_info_sorting_set_nth (ethi->sort_info,
@@ -1683,14 +1680,14 @@ ethi_change_sort_state (ETableHeaderItem *ethi, ETableCol *col)
 /*
  * Handles the events on the ETableHeaderItem, particularly it handles resizing
  */
-static int
+static gint
 ethi_event (GnomeCanvasItem *item, GdkEvent *e)
 {
 	ETableHeaderItem *ethi = E_TABLE_HEADER_ITEM (item);
 	GnomeCanvas *canvas = item->canvas;
 	const gboolean resizing = ETHI_RESIZING (ethi);
-	int x, y, start, col;
-	int was_maybe_drag = 0;
+	gint x, y, start, col;
+	gint was_maybe_drag = 0;
 
 	switch (e->type){
 	case GDK_ENTER_NOTIFY:
@@ -1707,7 +1704,7 @@ ethi_event (GnomeCanvasItem *item, GdkEvent *e)
 
 		convert (canvas, e->motion.x, e->motion.y, &x, &y);
 		if (resizing){
-			int new_width;
+			gint new_width;
 
 			if (ethi->resize_guide == NULL){
 				/* Quick hack until I actually bind the views */
@@ -1777,10 +1774,10 @@ ethi_event (GnomeCanvasItem *item, GdkEvent *e)
 		if (e->button.button != 1)
 			break;
 		else {
-			int width = 0;
+			gint width = 0;
 			g_signal_emit_by_name (ethi->eth,
 					       "request_width",
-					       (int)ethi->resize_col, &width);
+					       (gint)ethi->resize_col, &width);
 			/* Add 10 to stop it from "..."ing */
 			e_table_header_set_size (ethi->eth, ethi->resize_col, width + 10);
 
@@ -1883,49 +1880,49 @@ ethi_class_init (ETableHeaderItemClass *klass)
 
 	g_object_class_install_property (object_class, PROP_DND_CODE,
 					 g_param_spec_string ("dnd_code",
-							      _("DnD code"),
+							      "DnD code",
 							      /*_( */"XXX blurb" /*)*/,
 							      NULL,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_TABLE_FONT_DESC,
 					 g_param_spec_boxed ("font-desc",
-							     _("Font Description"),
+							     "Font Description",
 							     /*_( */"XXX blurb" /*)*/,
 							     PANGO_TYPE_FONT_DESCRIPTION,
 							     G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_FULL_HEADER,
 					 g_param_spec_object ("full_header",
-							      _("Full Header"),
+							      "Full Header",
 							      /*_( */"XXX blurb" /*)*/,
 							      E_TABLE_HEADER_TYPE,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_TABLE_HEADER,
 					 g_param_spec_object ("ETableHeader",
-							      _("Header"),
+							      "Header",
 							      /*_( */"XXX blurb" /*)*/,
 							      E_TABLE_HEADER_TYPE,
 							      G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_SORT_INFO,
 					 g_param_spec_object ("sort_info",
-							      _("Sort Info"),
+							      "Sort Info",
 							      /*_( */"XXX blurb" /*)*/,
 							      E_TABLE_SORT_INFO_TYPE,
 							      G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_TABLE,
 					 g_param_spec_object ("table",
-							      _("Table"),
+							      "Table",
 							      /*_( */"XXX blurb" /*)*/,
 							      E_TABLE_TYPE,
 							      G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_TREE,
 					 g_param_spec_object ("tree",
-							      _("Tree"),
+							      "Tree",
 							      /*_( */"XXX blurb" /*)*/,
 							      E_TREE_TYPE,
 							      G_PARAM_WRITABLE));
@@ -1936,11 +1933,11 @@ ethi_class_init (ETableHeaderItemClass *klass)
 	dnd_colormap = gtk_widget_get_default_colormap ();
 	remove_col_pixmap = gdk_pixmap_colormap_create_from_xpm_d (
 		NULL, dnd_colormap,
-		&remove_col_mask, NULL, remove_col_xpm);
+		&remove_col_mask, NULL, (gchar **) remove_col_xpm);
 
 	add_col_pixmap = gdk_pixmap_colormap_create_from_xpm_d (
 		NULL, dnd_colormap,
-		&add_col_mask, NULL, add_col_xpm);
+		&add_col_mask, NULL, (gchar **) add_col_xpm);
 
 	ethi_signals [BUTTON_PRESSED] =
 		g_signal_new ("button_pressed",
