@@ -1,24 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-table-sorted.c
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -45,10 +44,10 @@ G_DEFINE_TYPE (ETableSorted, ets, E_TABLE_SUBSET_TYPE)
 static void ets_sort_info_changed        (ETableSortInfo *info, ETableSorted *ets);
 static void ets_sort                     (ETableSorted *ets);
 static void ets_proxy_model_changed      (ETableSubset *etss, ETableModel *source);
-static void ets_proxy_model_row_changed  (ETableSubset *etss, ETableModel *source, int row);
-static void ets_proxy_model_cell_changed (ETableSubset *etss, ETableModel *source, int col, int row);
-static void ets_proxy_model_rows_inserted (ETableSubset *etss, ETableModel *source, int row, int count);
-static void ets_proxy_model_rows_deleted  (ETableSubset *etss, ETableModel *source, int row, int count);
+static void ets_proxy_model_row_changed  (ETableSubset *etss, ETableModel *source, gint row);
+static void ets_proxy_model_cell_changed (ETableSubset *etss, ETableModel *source, gint col, gint row);
+static void ets_proxy_model_rows_inserted (ETableSubset *etss, ETableModel *source, gint row, gint count);
+static void ets_proxy_model_rows_deleted  (ETableSubset *etss, ETableModel *source, gint row, gint count);
 
 static void
 ets_dispose (GObject *object)
@@ -65,7 +64,7 @@ ets_dispose (GObject *object)
 
 	if (ets->sort_info) {
 		g_signal_handler_disconnect (G_OBJECT (ets->sort_info),
-				             ets->sort_info_changed_id);
+					     ets->sort_info_changed_id);
 		g_object_unref(ets->sort_info);
 		ets->sort_info = NULL;
 	}
@@ -159,7 +158,7 @@ ets_sort_info_changed (ETableSortInfo *info, ETableSorted *ets)
 static void
 ets_proxy_model_changed (ETableSubset *subset, ETableModel *source)
 {
-	int rows, i;
+	gint rows, i;
 
 	rows = e_table_model_row_count(source);
 
@@ -178,7 +177,7 @@ ets_proxy_model_changed (ETableSubset *subset, ETableModel *source)
 }
 
 static void
-ets_proxy_model_row_changed (ETableSubset *subset, ETableModel *source, int row)
+ets_proxy_model_row_changed (ETableSubset *subset, ETableModel *source, gint row)
 {
 	if (!E_TABLE_SORTED(subset)->sort_idle_id)
 		E_TABLE_SORTED(subset)->sort_idle_id = g_idle_add_full(50, (GSourceFunc) ets_sort_idle, subset, NULL);
@@ -188,7 +187,7 @@ ets_proxy_model_row_changed (ETableSubset *subset, ETableModel *source, int row)
 }
 
 static void
-ets_proxy_model_cell_changed (ETableSubset *subset, ETableModel *source, int col, int row)
+ets_proxy_model_cell_changed (ETableSubset *subset, ETableModel *source, gint col, gint row)
 {
 	ETableSorted *ets = E_TABLE_SORTED(subset);
 	if (e_table_sorting_utils_affects_sort(ets->sort_info, ets->full_header, col))
@@ -198,11 +197,11 @@ ets_proxy_model_cell_changed (ETableSubset *subset, ETableModel *source, int col
 }
 
 static void
-ets_proxy_model_rows_inserted (ETableSubset *etss, ETableModel *source, int row, int count)
+ets_proxy_model_rows_inserted (ETableSubset *etss, ETableModel *source, gint row, gint count)
 {
- 	ETableModel *etm = E_TABLE_MODEL(etss);
+	ETableModel *etm = E_TABLE_MODEL(etss);
 	ETableSorted *ets = E_TABLE_SORTED(etss);
-	int i;
+	gint i;
 	gboolean full_change = FALSE;
 
 	if (count == 0) {
@@ -219,7 +218,7 @@ ets_proxy_model_rows_inserted (ETableSubset *etss, ETableModel *source, int row,
 		}
 	}
 
-	etss->map_table = g_realloc (etss->map_table, (etss->n_map + count) * sizeof(int));
+	etss->map_table = g_realloc (etss->map_table, (etss->n_map + count) * sizeof(gint));
 
 	for (; count > 0; count --) {
 		if (!full_change)
@@ -238,7 +237,7 @@ ets_proxy_model_rows_inserted (ETableSubset *etss, ETableModel *source, int row,
 					ets->insert_idle_id = g_idle_add_full(40, (GSourceFunc) ets_insert_idle, ets, NULL);
 				}
 				i = e_table_sorting_utils_insert(etss->source, ets->sort_info, ets->full_header, etss->map_table, etss->n_map, row);
-				memmove(etss->map_table + i + 1, etss->map_table + i, (etss->n_map - i) * sizeof(int));
+				memmove(etss->map_table + i + 1, etss->map_table + i, (etss->n_map - i) * sizeof(gint));
 			}
 		}
 		etss->map_table[i] = row;
@@ -258,12 +257,12 @@ ets_proxy_model_rows_inserted (ETableSubset *etss, ETableModel *source, int row,
 }
 
 static void
-ets_proxy_model_rows_deleted (ETableSubset *etss, ETableModel *source, int row, int count)
+ets_proxy_model_rows_deleted (ETableSubset *etss, ETableModel *source, gint row, gint count)
 {
 	ETableModel *etm = E_TABLE_MODEL(etss);
-	int i;
+	gint i;
 	gboolean shift;
-	int j;
+	gint j;
 
 	shift = row == etss->n_map - count;
 
@@ -272,7 +271,7 @@ ets_proxy_model_rows_deleted (ETableSubset *etss, ETableModel *source, int row,
 			if (etss->map_table[i] == row + j) {
 				if (shift)
 					e_table_model_pre_change (etm);
-				memmove (etss->map_table + i, etss->map_table + i + 1, (etss->n_map - i - 1) * sizeof(int));
+				memmove (etss->map_table + i, etss->map_table + i + 1, (etss->n_map - i - 1) * sizeof(gint));
 				etss->n_map --;
 				if (shift)
 					e_table_model_row_deleted (etm, i);
@@ -298,7 +297,7 @@ static void
 ets_sort(ETableSorted *ets)
 {
 	ETableSubset *etss = E_TABLE_SUBSET(ets);
-	static int reentering = 0;
+	static gint reentering = 0;
 	if (reentering)
 		return;
 	reentering = 1;
